package Locale::CLDR::Transformations::Any::Latin::Interindic;
# This file auto generated from Data\common\transforms\Latin-InterIndic.xml
#	on Sat 24 Oct  9:19:23 am GMT

use version;

our $VERSION = version->declare('v0.28.1');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moose;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => 'ArrayRef',
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̕)),
					result  => q(\uE03D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̃)),
					result  => q(\uE001\uE002),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:m̐)),
					result  => q(\uE001),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ḥ)),
					result  => q(\uE003),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:x)),
					result  => q(\uE015\uE04D\uE038),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔ā)),
					result  => q(\uE03E),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔ai)),
					result  => q(\uE048),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔au)),
					result  => q(\uE04C),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔ii)),
					result  => q(\uE040),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔ī)),
					result  => q(\uE040),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔i)),
					result  => q(\uE03F),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔ū)),
					result  => q(\uE042),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔u)),
					result  => q(\uE041),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔r̥̄)),
					result  => q(\uE044),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔r̥)),
					result  => q(\uE043),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔l̥̄)),
					result  => q(\uE063),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔lh)),
					result  => q(\uE062),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔l̥)),
					result  => q(\uE062),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔ē)),
					result  => q(\uE047),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔ō)),
					result  => q(\uE04B),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔a)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔ĕ)),
					result  => q(\uE045),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔ŏ)),
					result  => q(\uE049),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔e)),
					result  => q(\uE046),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:̔o)),
					result  => q(\uE04A),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:ā)),
					result  => q(\uE03E),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:ai)),
					result  => q(\uE048),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:au)),
					result  => q(\uE04C),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:ii)),
					result  => q(\uE040),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:ī)),
					result  => q(\uE040),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:i)),
					result  => q(\uE03F),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:ū)),
					result  => q(\uE042),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:u)),
					result  => q(\uE041),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:r̥̄)),
					result  => q(\uE044),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:r̥a)),
					result  => q(\uE043),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:r̥)),
					result  => q(\uE043),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:l̥̄)),
					result  => q(\uE063),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:lh)),
					result  => q(\uE062),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:l̥)),
					result  => q(\uE062),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:ē)),
					result  => q(\uE047),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:ō)),
					result  => q(\uE04B),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:ĕ)),
					result  => q(\uE045),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:ŏ)),
					result  => q(\uE049),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:e)),
					result  => q(\uE046),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[[-] + [bcdfghjklmnpqrstvwxyz] + [क-ह] + [ক-হ] + [ਕ-ਹ] + [ક-હ] + [କ-ହ] + [க-ஹ] + [క-హ] + [ಕ-ಹ] + [ക-ഹ]]))),
					after   => q(),
					replace => q((?^u:o)),
					result  => q(\uE04A),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ā)),
					result  => q(\uE006),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ai)),
					result  => q(\uE010),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:au)),
					result  => q(\uE014),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ī)),
					result  => q(\uE008),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:i)),
					result  => q(\uE007),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ū)),
					result  => q(\uE00A),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:u)),
					result  => q(\uE009),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:r̥̄)),
					result  => q(\uE060),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:r̥)),
					result  => q(\uE00B),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:l̥̄)),
					result  => q(\uE061),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lh)),
					result  => q(\uE00C),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:l̥)),
					result  => q(\uE00C),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ē)),
					result  => q(\uE00F),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ō)),
					result  => q(\uE013),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:a)),
					result  => q(\uE005),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ĕ)),
					result  => q(\uE00D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ŏ)),
					result  => q(\uE011),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:e)),
					result  => q(\uE00E),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'om)),
					result  => q(\uE050),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:o)),
					result  => q(\uE012),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:r̥)),
					replace => q((?^u:n)),
					result  => q(\uE028|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:l̥)),
					replace => q((?^u:n)),
					result  => q(\uE028|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:na)),
					replace => q((?^u:n)),
					result  => q(\uE028|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[kg])),
					replace => q((?^u:ṅ)),
					result  => q(\uE002),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:ṅ)),
					replace => q((?^u:ṅ)),
					result  => q(\uE002),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[cj])),
					replace => q((?^u:n̄)),
					result  => q(\uE002),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:ñ)),
					replace => q((?^u:n̄)),
					result  => q(\uE002),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[tdn]̣)),
					replace => q((?^u:ṇ)),
					result  => q(\uE002),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[tdn])),
					replace => q((?^u:n)),
					result  => q(\uE002),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[pbm])),
					replace => q((?^u:m)),
					result  => q(\uE002),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[ylvshr])),
					replace => q((?^u:n)),
					result  => q(\uE002),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ṁ)),
					result  => q(\uE002),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:q)),
					result  => q(\uE058|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ḵẖ)),
					result  => q(\uE059|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ġ)),
					result  => q(\uE05A),
					revisit => 6,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:z)),
					result  => q(\uE05B|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:f)),
					result  => q(\uE05E|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ṯ)),
					result  => q(\uE083),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ẏ)),
					result  => q(\uE05F|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ḻ)),
					result  => q(\uE034|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ṉ)),
					result  => q(\uE029|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ṅ)),
					result  => q(\uE019|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ñ)),
					result  => q(\uE01E|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ṇ)),
					result  => q(\uE023|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ṭh)),
					result  => q(\uE020|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ṭ)),
					result  => q(\uE01F|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ṛh)),
					result  => q(\uE05D|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ṛ)),
					result  => q(\uE05C|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ḍh)),
					result  => q(\uE022|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ḍ)),
					result  => q(\uE021|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kh)),
					result  => q(\uE016|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:k)),
					result  => q(\uE015|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gh)),
					result  => q(\uE018|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:g)),
					result  => q(\uE017|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ch)),
					result  => q(\uE01B|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:c)),
					result  => q(\uE01A|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:jh)),
					result  => q(\uE01D|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:j)),
					result  => q(\uE01C|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ny)),
					result  => q(\uE01E|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tth)),
					result  => q(\uE020|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ddh)),
					result  => q(\uE022|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:th)),
					result  => q(\uE025|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:t)),
					result  => q(\uE024|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dh)),
					result  => q(\uE027|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:d)),
					result  => q(\uE026|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:n)),
					result  => q(\uE028|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ph)),
					result  => q(\uE02B|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:p)),
					result  => q(\uE02A|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bh)),
					result  => q(\uE02D|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:b)),
					result  => q(\uE02C|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:m)),
					result  => q(\uE02E|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:y)),
					result  => q(\uE02F|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ṟ)),
					result  => q(\uE031|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:r)),
					result  => q(\uE030|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ḷ)),
					result  => q(\uE033|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:l)),
					result  => q(\uE032|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:v)),
					result  => q(\uE035|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ẇ)),
					result  => q(\uE081|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:w)),
					result  => q(\uE035|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sh)),
					result  => q(\uE036|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ss)),
					result  => q(\uE037|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ṣ)),
					result  => q(\uE037|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ś)),
					result  => q(\uE036|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:s)),
					result  => q(\uE038|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:h)),
					result  => q(\uE039|\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\Q'\E)),
					result  => q(\uE064),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE064\Q'\E)),
					result  => q(\uE065),
					revisit => 0,
				},
				{
					before  => q((?^u:[--])),
					after   => q(),
					replace => q((?^u:\Q'\E)),
					result  => q(\uE002),
					revisit => 0,
				},
				{
					before  => q((?^u:[-])),
					after   => q(),
					replace => q((?^u:\Q'\E)),
					result  => q(\uE001),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Dā)),
					result  => q(\uE03E),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Dai)),
					result  => q(\uE048),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Dau)),
					result  => q(\uE04C),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Dii)),
					result  => q(\uE040),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Dī)),
					result  => q(\uE040),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Di)),
					result  => q(\uE03F),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Dū)),
					result  => q(\uE042),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Du)),
					result  => q(\uE041),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Dr̥̄)),
					result  => q(\uE044),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Dr̥a)),
					result  => q(\uE043),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Dr̥)),
					result  => q(\uE043),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Dl̥̄)),
					result  => q(\uE063),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Dlh)),
					result  => q(\uE062),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Dl̥)),
					result  => q(\uE062),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Dē)),
					result  => q(\uE047),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Dō)),
					result  => q(\uE04B),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Da)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Dĕ)),
					result  => q(\uE045),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Dŏ)),
					result  => q(\uE049),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04De)),
					result  => q(\uE046),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04Do)),
					result  => q(\uE04A),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'ā)),
					result  => q(\uE006),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'ai)),
					result  => q(\uE010),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'au)),
					result  => q(\uE014),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'ī)),
					result  => q(\uE008),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'i)),
					result  => q(\uE007),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'ū)),
					result  => q(\uE00A),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'u)),
					result  => q(\uE009),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'r̥̄)),
					result  => q(\uE060),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'r̥)),
					result  => q(\uE00B),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'l̥̄)),
					result  => q(\uE061),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'l̥)),
					result  => q(\uE00C),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'ē)),
					result  => q(\uE00F),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'ō)),
					result  => q(\uE013),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'a)),
					result  => q(\uE005),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'ĕ)),
					result  => q(\uE00D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'ŏ)),
					result  => q(\uE011),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'e)),
					result  => q(\uE00E),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\uE04D'o)),
					result  => q(\uE012),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'ā)),
					result  => q(\uE006),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'ai)),
					result  => q(\uE010),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'au)),
					result  => q(\uE014),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'ī)),
					result  => q(\uE008),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'i)),
					result  => q(\uE007),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'ū)),
					result  => q(\uE00A),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'u)),
					result  => q(\uE009),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'r̥̄)),
					result  => q(\uE060),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'r̥)),
					result  => q(\uE00B),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'l̥̄)),
					result  => q(\uE061),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'l̥)),
					result  => q(\uE00C),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'ē)),
					result  => q(\uE00F),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'ō)),
					result  => q(\uE013),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'a)),
					result  => q(\uE005),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'ĕ)),
					result  => q(\uE00D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'ŏ)),
					result  => q(\uE011),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'e)),
					result  => q(\uE00E),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:'o)),
					result  => q(\uE012),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[[bcdfghjklmnpqrstvwxyz]]))),
					replace => q((?^u:\uE04D)),
					result  => q(\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:\Q'\E)),
					replace => q((?^u:\uE04D)),
					result  => q(\uE04D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[])),
					replace => q((?^u:\uE04D)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʔ)),
					result  => q(\uE082),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(\uE066),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:1)),
					result  => q(\uE067),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:2)),
					result  => q(\uE068),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:3)),
					result  => q(\uE069),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:4)),
					result  => q(\uE06A),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:5)),
					result  => q(\uE06B),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:6)),
					result  => q(\uE06C),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:7)),
					result  => q(\uE06D),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:8)),
					result  => q(\uE06E),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:9)),
					result  => q(\uE06F),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:')),
					result  => q(),
					revisit => 0,
				},
			]
		},
	] },
);

no Moose;
__PACKAGE__->meta->make_immutable;

1;

# vim: tabstop=4
