package Locale::CLDR::Transformations::Any::Es_fonipa::Zh;
# This file auto generated from Data\common\transforms\es_FONIPA-zh.xml
#	on Sat 24 Oct  9:19:28 am GMT

use version;

our $VERSION = version->declare('v0.28.1');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moose;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => 'ArrayRef',
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ð)),
					result  => q(),
					revisit => 1,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ɣ)),
					result  => q(),
					revisit => 1,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ŋ)),
					result  => q(),
					revisit => 1,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:θ)),
					result  => q(),
					revisit => 1,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ɾ)),
					result  => q(),
					revisit => 1,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ff)),
					result  => q(f),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kk)),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mm)),
					result  => q(m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nn)),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pp)),
					result  => q(p),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tt)),
					result  => q(t),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tʧ)),
					result  => q(ʧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:aa)),
					result  => q(a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:oi̯)),
					result  => q(oi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:oo)),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:uu)),
					result  => q(u),
					revisit => 0,
				},
				{
					before  => q((?^u:[^dgktx])),
					after   => q(),
					replace => q((?^u:ei̯)),
					result  => q(e),
					revisit => 0,
				},
				{
					before  => q((?^u:[^-\ .$])),
					after   => q(),
					replace => q((?^u:eu̯)),
					result  => q(eu),
					revisit => 0,
				},
				{
					before  => q((?^u:[^-\ .$])),
					after   => q(),
					replace => q((?^u:ou̯)),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q((?^u:[^j])),
					after   => q(),
					replace => q((?^u:ui)),
					result  => q(wi),
					revisit => 0,
				},
				{
					before  => q((?^u:(?[![-\ $]]))),
					after   => q((?^u:[bp])),
					replace => q((?^u:m)),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:s[θs])),
					result  => q(s),
					revisit => 0,
				},
				{
					before  => q((?^u:[^ʧ])),
					after   => q(),
					replace => q((?^u:jo)),
					result  => q(io),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(Null),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q((?^u:an(?[![aeijouw]]))),
					replace => q((?^u:j)),
					result  => q(i),
					revisit => 0,
				},
				{
					before  => q((?^u:[g.$])),
					after   => q(),
					replace => q((?^u:wai̯)),
					result  => q(wai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:wai̯)),
					result  => q(uai̯),
					revisit => 0,
				},
				{
					before  => q((?^u:[g.$])),
					after   => q(),
					replace => q((?^u:wau̯)),
					result  => q(wau),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:wau̯)),
					result  => q(uau̯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:jau̯)),
					result  => q(iau̯),
					revisit => 0,
				},
				{
					before  => q((?^u:[^jw])),
					after   => q((?^u:[^n])),
					replace => q((?^u:ao)),
					result  => q(au̯),
					revisit => 0,
				},
				{
					before  => q((?^u:[^jw])),
					after   => q((?^u:n[aeijouw])),
					replace => q((?^u:ao)),
					result  => q(au̯),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(Null),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:\Q'\E)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ai̯)),
					result  => q(艾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:an)),
					result  => q(安),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:au̯)),
					result  => q(奥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:a)),
					result  => q(阿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bai̯)),
					result  => q(拜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ban)),
					result  => q(班),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bau̯)),
					result  => q(包),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ba)),
					result  => q(巴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ben)),
					result  => q(本),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:be)),
					result  => q(贝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:bin)),
					result  => q(宾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bi)),
					result  => q(比),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bja)),
					result  => q(比亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:bjen)),
					result  => q(比恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bje)),
					result  => q(别),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bju)),
					result  => q(比乌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:bon)),
					result  => q(邦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bo)),
					result  => q(博),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:bun)),
					result  => q(本),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bu)),
					result  => q(布),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:bwan)),
					result  => q(布安),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bwa)),
					result  => q(布阿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:bwen)),
					result  => q(布恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bwe)),
					result  => q(布埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:bwin)),
					result  => q(布因),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bwi)),
					result  => q(布伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bwo)),
					result  => q(博),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:b)),
					result  => q(布),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:βai̯)),
					result  => q(瓦伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:βan)),
					result  => q(万),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:βau̯)),
					result  => q(沃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:βa)),
					result  => q(瓦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:βen)),
					result  => q(文),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:βe)),
					result  => q(韦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:βin)),
					result  => q(温),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:βi)),
					result  => q(维),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:βja)),
					result  => q(维亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:βjen)),
					result  => q(维恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:βje)),
					result  => q(维耶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:βju)),
					result  => q(维乌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:βon)),
					result  => q(翁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:βo)),
					result  => q(沃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:βun)),
					result  => q(文),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:βu)),
					result  => q(武),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:βwan)),
					result  => q(万),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:βwa)),
					result  => q(瓦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:βwen)),
					result  => q(文),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:βwe)),
					result  => q(武埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:βwi)),
					result  => q(维),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:βwo)),
					result  => q(沃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:β)),
					result  => q(夫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dai̯)),
					result  => q(代),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:dan)),
					result  => q(丹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dau̯)),
					result  => q(道),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:da)),
					result  => q(达),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dei̯)),
					result  => q(代),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:den)),
					result  => q(登),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:de)),
					result  => q(德),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:din)),
					result  => q(丁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:di)),
					result  => q(迪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dja)),
					result  => q(迪亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:djen)),
					result  => q(迪恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dje)),
					result  => q(迭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dju)),
					result  => q(迪乌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:don)),
					result  => q(东),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:do)),
					result  => q(多),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:dun)),
					result  => q(敦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:du)),
					result  => q(杜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:dwan)),
					result  => q(端),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dwa)),
					result  => q(杜阿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:dwen)),
					result  => q(敦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dwe)),
					result  => q(杜埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dwi)),
					result  => q(杜伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dwo)),
					result  => q(多),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[-\ $])),
					replace => q((?^u:d)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:d)),
					result  => q(德),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ei̯)),
					result  => q(埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:en)),
					result  => q(恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:eu̯)),
					result  => q(欧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:e)),
					result  => q(埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fai̯)),
					result  => q(法伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:fan)),
					result  => q(凡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fau̯)),
					result  => q(福),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fa)),
					result  => q(法),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fe)),
					result  => q(费),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:fin)),
					result  => q(芬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fi)),
					result  => q(菲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fja)),
					result  => q(菲亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:fjen)),
					result  => q(菲恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fje)),
					result  => q(菲耶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fju)),
					result  => q(菲乌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:fon)),
					result  => q(丰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fo)),
					result  => q(福),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:fun)),
					result  => q(丰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fu)),
					result  => q(富),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:fwan)),
					result  => q(富安),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fwa)),
					result  => q(富阿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:fwen)),
					result  => q(丰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fwe)),
					result  => q(富埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fwi)),
					result  => q(富伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fwo)),
					result  => q(福),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[-\ $])),
					replace => q((?^u:f)),
					result  => q(夫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:f)),
					result  => q(弗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gai̯)),
					result  => q(盖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:gan)),
					result  => q(甘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gau̯)),
					result  => q(高),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ga)),
					result  => q(加),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gei̯)),
					result  => q(盖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:gen)),
					result  => q(根),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ge)),
					result  => q(格),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:gin)),
					result  => q(金),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gi)),
					result  => q(吉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gja)),
					result  => q(吉亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:gjen)),
					result  => q(吉恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gje)),
					result  => q(吉耶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gju)),
					result  => q(吉乌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:gon)),
					result  => q(贡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:go)),
					result  => q(戈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:gun)),
					result  => q(贡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gu)),
					result  => q(古),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[$])),
					replace => q((?^u:gwan)),
					result  => q(古安),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:gwan)),
					result  => q(关),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gwa)),
					result  => q(瓜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:gwen)),
					result  => q(古恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gwe)),
					result  => q(圭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gwi)),
					result  => q(圭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gwo)),
					result  => q(果),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:g)),
					result  => q(格),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:in)),
					result  => q(因),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:i)),
					result  => q(伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʝai̯)),
					result  => q(亚伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʝan)),
					result  => q(扬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʝau̯)),
					result  => q(尧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʝa)),
					result  => q(亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʝen)),
					result  => q(延),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʝe)),
					result  => q(耶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʝin)),
					result  => q(因),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʝi)),
					result  => q(伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʝon)),
					result  => q(永),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʝo)),
					result  => q(约),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʝun)),
					result  => q(云),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʝu)),
					result  => q(尤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʝwan)),
					result  => q(元),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʝwa)),
					result  => q(尤阿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʝwen)),
					result  => q(云),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʝwe)),
					result  => q(尤埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʝwi)),
					result  => q(尤伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʝwo)),
					result  => q(约),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʝ)),
					result  => q(伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kai̯)),
					result  => q(凯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:kan)),
					result  => q(坎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kau̯)),
					result  => q(考),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ka)),
					result  => q(卡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kei̯)),
					result  => q(凯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ken)),
					result  => q(肯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ke)),
					result  => q(克),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:kin)),
					result  => q(金),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ki)),
					result  => q(基),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kja)),
					result  => q(基亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:kjen)),
					result  => q(基恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kje)),
					result  => q(基耶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kju)),
					result  => q(基乌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:kon)),
					result  => q(孔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ko)),
					result  => q(科),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:kun)),
					result  => q(昆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ku)),
					result  => q(库),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:kwan)),
					result  => q(宽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kwa)),
					result  => q(夸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:kwen)),
					result  => q(昆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kwe)),
					result  => q(库埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:kwin)),
					result  => q(昆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kwi)),
					result  => q(奎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kwo)),
					result  => q(阔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:k)),
					result  => q(克),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[^n])),
					replace => q((?^u:lae)),
					result  => q(莱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lai̯)),
					result  => q(莱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:lan)),
					result  => q(兰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lau̯)),
					result  => q(劳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:la)),
					result  => q(拉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:len)),
					result  => q(伦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:le)),
					result  => q(莱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:lin)),
					result  => q(林),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:li)),
					result  => q(利),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lja)),
					result  => q(利亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ljen)),
					result  => q(连),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lje)),
					result  => q(列),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lju)),
					result  => q(柳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:lon)),
					result  => q(隆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lo)),
					result  => q(洛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:lun)),
					result  => q(伦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lu)),
					result  => q(卢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:lwan)),
					result  => q(卢安),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lwa)),
					result  => q(卢阿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:lwen)),
					result  => q(伦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lwe)),
					result  => q(卢埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lwi)),
					result  => q(卢伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lwo)),
					result  => q(洛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:l)),
					result  => q(尔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʎan)),
					result  => q(良),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʎau̯)),
					result  => q(廖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʎa)),
					result  => q(利亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʎen)),
					result  => q(连),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʎe)),
					result  => q(列),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʎin)),
					result  => q(林),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʎi)),
					result  => q(利),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʎon)),
					result  => q(利翁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʎo)),
					result  => q(略),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʎu)),
					result  => q(柳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʎwan)),
					result  => q(柳安),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʎwa)),
					result  => q(柳阿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʎwen)),
					result  => q(柳恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʎwe)),
					result  => q(柳埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʎwi)),
					result  => q(柳伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʎwo)),
					result  => q(略),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʎ)),
					result  => q(尔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mai̯)),
					result  => q(迈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:man)),
					result  => q(曼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:martin)),
					result  => q(马丁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mau̯)),
					result  => q(毛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ma)),
					result  => q(马),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:men)),
					result  => q(门),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:me)),
					result  => q(梅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:min)),
					result  => q(明),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mi)),
					result  => q(米),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mja)),
					result  => q(米亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:mjen)),
					result  => q(缅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mje)),
					result  => q(米耶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mju)),
					result  => q(缪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:mon)),
					result  => q(蒙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mo)),
					result  => q(莫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:mun)),
					result  => q(蒙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mu)),
					result  => q(穆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:mwan)),
					result  => q(穆安),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mwa)),
					result  => q(穆阿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:mwen)),
					result  => q(门),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mwe)),
					result  => q(穆埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:mwin)),
					result  => q(穆因),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mwi)),
					result  => q(穆伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mwo)),
					result  => q(莫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:m)),
					result  => q(姆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nai̯)),
					result  => q(奈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:nan)),
					result  => q(南),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nau̯)),
					result  => q(瑙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:na)),
					result  => q(纳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:nen)),
					result  => q(嫩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ne)),
					result  => q(内),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:nin)),
					result  => q(宁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ni)),
					result  => q(尼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nja)),
					result  => q(尼亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:njen)),
					result  => q(年),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nje)),
					result  => q(涅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nju)),
					result  => q(纽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:non)),
					result  => q(农),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:no)),
					result  => q(诺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:nun)),
					result  => q(嫩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nu)),
					result  => q(努),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:nwan)),
					result  => q(努安),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nwa)),
					result  => q(努阿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:nwen)),
					result  => q(农),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nwe)),
					result  => q(努埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nwi)),
					result  => q(努伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nwo)),
					result  => q(诺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:n)),
					result  => q(恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ɲan)),
					result  => q(尼扬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ɲau̯)),
					result  => q(尼奥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ɲa)),
					result  => q(尼亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ɲen)),
					result  => q(年),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ɲe)),
					result  => q(涅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ɲin)),
					result  => q(宁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ɲi)),
					result  => q(尼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ɲon)),
					result  => q(尼翁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ɲo)),
					result  => q(尼奥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ɲu)),
					result  => q(纽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ɲwan)),
					result  => q(纽安),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ɲwa)),
					result  => q(纽阿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ɲwen)),
					result  => q(纽恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ɲwe)),
					result  => q(纽埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ɲwi)),
					result  => q(纽伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ɲwo)),
					result  => q(尼奥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:on)),
					result  => q(翁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ou̯)),
					result  => q(欧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:o)),
					result  => q(奥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pai̯)),
					result  => q(派),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:pan)),
					result  => q(潘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pau̯)),
					result  => q(保),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pa)),
					result  => q(帕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:pen)),
					result  => q(彭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pe)),
					result  => q(佩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:pin)),
					result  => q(平),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pi)),
					result  => q(皮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pja)),
					result  => q(皮亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:pjen)),
					result  => q(皮恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pje)),
					result  => q(彼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pju)),
					result  => q(皮乌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:pon)),
					result  => q(蓬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:po)),
					result  => q(波),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:pun)),
					result  => q(蓬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pu)),
					result  => q(普),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:pwan)),
					result  => q(普安),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pwa)),
					result  => q(普阿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:pwen)),
					result  => q(蓬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pwe)),
					result  => q(普埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pwi)),
					result  => q(普伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pwo)),
					result  => q(波),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:p)),
					result  => q(普),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:rai̯)),
					result  => q(赖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ran)),
					result  => q(兰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:rau̯)),
					result  => q(劳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ra)),
					result  => q(拉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ren)),
					result  => q(伦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:re)),
					result  => q(雷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:rin)),
					result  => q(林),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ri)),
					result  => q(里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:rja)),
					result  => q(里亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:rjen)),
					result  => q(连),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:rje)),
					result  => q(列),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:rju)),
					result  => q(留),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ron)),
					result  => q(龙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ro)),
					result  => q(罗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:run)),
					result  => q(伦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ru)),
					result  => q(鲁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:rwan)),
					result  => q(鲁安),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:rwa)),
					result  => q(鲁阿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:rwen)),
					result  => q(伦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:rwe)),
					result  => q(鲁埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:rwi)),
					result  => q(鲁伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:rwo)),
					result  => q(罗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:r)),
					result  => q(R),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sai̯)),
					result  => q(赛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:san)),
					result  => q(桑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sau̯)),
					result  => q(绍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sa)),
					result  => q(萨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:sen)),
					result  => q(森),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:se)),
					result  => q(塞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:sin)),
					result  => q(辛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:si)),
					result  => q(西),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sja)),
					result  => q(西亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:sjen)),
					result  => q(先),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sje)),
					result  => q(谢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sju)),
					result  => q(休),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:son)),
					result  => q(松),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:so)),
					result  => q(索),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:sun)),
					result  => q(孙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:su)),
					result  => q(苏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:swan)),
					result  => q(苏安),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:swa)),
					result  => q(苏阿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:swen)),
					result  => q(孙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:swe)),
					result  => q(苏埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:swi)),
					result  => q(绥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:swo)),
					result  => q(索),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:s)),
					result  => q(斯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tai̯)),
					result  => q(泰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:tan)),
					result  => q(坦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tau̯)),
					result  => q(陶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ta)),
					result  => q(塔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tei̯)),
					result  => q(泰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ten)),
					result  => q(滕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:te)),
					result  => q(特),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:tin)),
					result  => q(廷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ti)),
					result  => q(蒂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tja)),
					result  => q(蒂亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:tjen)),
					result  => q(蒂恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tje)),
					result  => q(铁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tju)),
					result  => q(蒂乌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ton)),
					result  => q(通),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:to)),
					result  => q(托),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tsa)),
					result  => q(察),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:tsen)),
					result  => q(岑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tse)),
					result  => q(采),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:tsin)),
					result  => q(钦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tsi)),
					result  => q(齐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tso)),
					result  => q(措),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:tsun)),
					result  => q(聪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tsu)),
					result  => q(楚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ts)),
					result  => q(茨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:tun)),
					result  => q(通),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tu)),
					result  => q(图),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:twan)),
					result  => q(图安),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:twa)),
					result  => q(图阿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:twen)),
					result  => q(通),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:twe)),
					result  => q(图埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:twi)),
					result  => q(图伊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:two)),
					result  => q(托),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:t)),
					result  => q(特),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʧai̯)),
					result  => q(柴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʧan)),
					result  => q(钱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʧau̯)),
					result  => q(乔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʧa)),
					result  => q(查),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʧen)),
					result  => q(琴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʧe)),
					result  => q(切),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʧin)),
					result  => q(钦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʧi)),
					result  => q(奇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʧjan)),
					result  => q(钱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʧja)),
					result  => q(恰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʧjen)),
					result  => q(钱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʧje)),
					result  => q(切),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʧjon)),
					result  => q(琼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʧju)),
					result  => q(丘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʧon)),
					result  => q(琼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʧo)),
					result  => q(乔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʧun)),
					result  => q(琼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʧu)),
					result  => q(丘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʧwan)),
					result  => q(丘安),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʧwa)),
					result  => q(丘阿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:ʧwen)),
					result  => q(琼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʧwe)),
					result  => q(丘埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʧwi)),
					result  => q(崔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʧwo)),
					result  => q(乔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ʧ)),
					result  => q(奇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:un)),
					result  => q(温),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:u)),
					result  => q(乌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:wan)),
					result  => q(万),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:wa)),
					result  => q(瓦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:wen)),
					result  => q(温),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:we)),
					result  => q(韦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:win)),
					result  => q(温),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:wi)),
					result  => q(维),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:won)),
					result  => q(翁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:wo)),
					result  => q(沃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xai̯)),
					result  => q(海),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:xan)),
					result  => q(汉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xau̯)),
					result  => q(豪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xa)),
					result  => q(哈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xei̯)),
					result  => q(黑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:xen)),
					result  => q(亨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xe)),
					result  => q(赫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:xin)),
					result  => q(欣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xi)),
					result  => q(希),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xja)),
					result  => q(希亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:xjen)),
					result  => q(希恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xje)),
					result  => q(希耶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xju)),
					result  => q(休),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:xon)),
					result  => q(洪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xo)),
					result  => q(霍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:xun)),
					result  => q(洪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xu)),
					result  => q(胡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:xwan)),
					result  => q(胡安),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xwa)),
					result  => q(华),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:(?[![aeijouw]]))),
					replace => q((?^u:xwen)),
					result  => q(洪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xwe)),
					result  => q(胡埃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xwi)),
					result  => q(惠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xwo)),
					result  => q(霍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:x)),
					result  => q(赫),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(Null),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:R)),
					result  => q(尔),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(Null),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q((?^u:[-\ $])),
					after   => q(),
					replace => q((?^u:东)),
					result  => q(栋),
					revisit => 0,
				},
				{
					before  => q((?^u:[-\ $])),
					after   => q(),
					replace => q((?^u:南)),
					result  => q(楠),
					revisit => 0,
				},
				{
					before  => q((?^u:[-\ $])),
					after   => q(),
					replace => q((?^u:西)),
					result  => q(锡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[-\ $])),
					replace => q((?^u:海)),
					result  => q(亥),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(NFC),
				},
			]
		},
	] },
);

no Moose;
__PACKAGE__->meta->make_immutable;

1;

# vim: tabstop=4
