package Locale::CLDR::Transformations::Any::Traditional::Simplified;
# This file auto generated from Data\common\transforms\Simplified-Traditional.xml
#	on Sat 24 Oct  9:19:25 am GMT

use version;

our $VERSION = version->declare('v0.28.1');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moose;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => 'ArrayRef',
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:」)),
					result  => q(”),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:「)),
					result  => q(“),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:龜)),
					result  => q(龟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:龕)),
					result  => q(龛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:龔)),
					result  => q(龚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:龐)),
					result  => q(庞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:龎)),
					result  => q(厐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:龍)),
					result  => q(龙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齷)),
					result  => q(龌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齶)),
					result  => q(腭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齲)),
					result  => q(龋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齬)),
					result  => q(龉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齪)),
					result  => q(龊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齦)),
					result  => q(龈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齡)),
					result  => q(龄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齠)),
					result  => q(龆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齟)),
					result  => q(龃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齜)),
					result  => q(龇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齙)),
					result  => q(龅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齗)),
					result  => q(龂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齕)),
					result  => q(龁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齔)),
					result  => q(龀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齒)),
					result  => q(齿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齏)),
					result  => q(齑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齋)),
					result  => q(斋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齊)),
					result  => q(齐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鼴)),
					result  => q(鼹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鼉)),
					result  => q(鼍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:黿)),
					result  => q(鼋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:黽)),
					result  => q(黾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:黷)),
					result  => q(黩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:黶)),
					result  => q(黡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:黲)),
					result  => q(黪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:黨)),
					result  => q(党),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:點)),
					result  => q(点),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:黌)),
					result  => q(黉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:黃)),
					result  => q(黄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:麩)),
					result  => q(麸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:麥)),
					result  => q(麦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:麗)),
					result  => q(丽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鹽)),
					result  => q(盐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鹼)),
					result  => q(碱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鹺)),
					result  => q(鹾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鸞)),
					result  => q(鸾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鸝)),
					result  => q(鹂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鸛)),
					result  => q(鹳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鸚)),
					result  => q(鹦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鸘)),
					result  => q(鹴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鸕)),
					result  => q(鸬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鸏)),
					result  => q(鹲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鸌)),
					result  => q(鹱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鸇)),
					result  => q(鹯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鸂)),
					result  => q(㶉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷿)),
					result  => q(䴙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷽)),
					result  => q(鸴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷺)),
					result  => q(鹭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷹)),
					result  => q(鹰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷸)),
					result  => q(鹬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷳)),
					result  => q(鹇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷲)),
					result  => q(鹫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷯)),
					result  => q(鹩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷫)),
					result  => q(鹔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷦)),
					result  => q(鹪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷥)),
					result  => q(鸶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷚)),
					result  => q(鹨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷙)),
					result  => q(鸷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷗)),
					result  => q(鸥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷖)),
					result  => q(鹥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷓)),
					result  => q(鹧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷊)),
					result  => q(鹝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷈)),
					result  => q(䴘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷂)),
					result  => q(鹞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷁)),
					result  => q(鹢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶼)),
					result  => q(鹣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶻)),
					result  => q(鹘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶺)),
					result  => q(鹡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶹)),
					result  => q(鹠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶴)),
					result  => q(鹤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶲)),
					result  => q(鹟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶯)),
					result  => q(莺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶬)),
					result  => q(鸧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶪)),
					result  => q(䴗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶩)),
					result  => q(鹜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶥)),
					result  => q(鹛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶡)),
					result  => q(鹖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶚)),
					result  => q(鹗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶘)),
					result  => q(鹕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶖)),
					result  => q(鹙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶓)),
					result  => q(鹋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶊)),
					result  => q(鹒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶉)),
					result  => q(鹑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶇)),
					result  => q(鸫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鶄)),
					result  => q(䴖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵾)),
					result  => q(鹍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵷)),
					result  => q(鹓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵲)),
					result  => q(鹊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵯)),
					result  => q(鹎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵮)),
					result  => q(鹐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵬)),
					result  => q(鹏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵪)),
					result  => q(鹌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵡)),
					result  => q(鹉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵠)),
					result  => q(鹄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵝)),
					result  => q(鹅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵜)),
					result  => q(鹈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵓)),
					result  => q(鹁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵒)),
					result  => q(鹆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵑)),
					result  => q(鹃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵐)),
					result  => q(鹀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵃)),
					result  => q(鸼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵂)),
					result  => q(鸺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鵁)),
					result  => q(䴔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴿)),
					result  => q(鸽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴻)),
					result  => q(鸿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴷)),
					result  => q(䴕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴴)),
					result  => q(鸻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴰)),
					result  => q(鸹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴯)),
					result  => q(鸸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴨)),
					result  => q(鸭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴦)),
					result  => q(鸯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴣)),
					result  => q(鸪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴟)),
					result  => q(鸱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴞)),
					result  => q(鸮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴝)),
					result  => q(鸲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴛)),
					result  => q(鸳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴕)),
					result  => q(鸵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴒)),
					result  => q(鸰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴉)),
					result  => q(鸦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴇)),
					result  => q(鸨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鴆)),
					result  => q(鸩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鳾)),
					result  => q(䴓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鳶)),
					result  => q(鸢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鳴)),
					result  => q(鸣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鳳)),
					result  => q(凤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鳲)),
					result  => q(鸤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鳩)),
					result  => q(鸠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鳥)),
					result  => q(鸟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱺)),
					result  => q(鲡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱸)),
					result  => q(鲈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱯)),
					result  => q(鳠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱭)),
					result  => q(鲚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱨)),
					result  => q(鲿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱧)),
					result  => q(鳢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱤)),
					result  => q(鳡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱣)),
					result  => q(鳣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱠)),
					result  => q(鲙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱟)),
					result  => q(鲎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱝)),
					result  => q(鲼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱘)),
					result  => q(鲟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱗)),
					result  => q(鳞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱖)),
					result  => q(鳜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱔)),
					result  => q(鳝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱒)),
					result  => q(鳟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱈)),
					result  => q(鳕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱅)),
					result  => q(鳙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱂)),
					result  => q(鳉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰾)),
					result  => q(鳔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰼)),
					result  => q(鳛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰻)),
					result  => q(鳗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰺)),
					result  => q(鲹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰹)),
					result  => q(鲣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰷)),
					result  => q(鲦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰵)),
					result  => q(鳘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰳)),
					result  => q(鳓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰱)),
					result  => q(鲢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰮)),
					result  => q(鳁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰭)),
					result  => q(鳍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰩)),
					result  => q(鳐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰨)),
					result  => q(鳎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰥)),
					result  => q(鳏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰣)),
					result  => q(鲥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰠)),
					result  => q(鳋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰟)),
					result  => q(鳑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰜)),
					result  => q(鳒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰓)),
					result  => q(鳃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰒)),
					result  => q(鳆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰏)),
					result  => q(鲾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰍)),
					result  => q(鳅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰉)),
					result  => q(鳇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰈)),
					result  => q(鲽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰃)),
					result  => q(鳂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰂)),
					result  => q(鲗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰁)),
					result  => q(鳈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯿)),
					result  => q(鳊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯽)),
					result  => q(鲫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯷)),
					result  => q(鳀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯴)),
					result  => q(鲺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯰)),
					result  => q(鲶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯫)),
					result  => q(鲰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯪)),
					result  => q(鲮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯨)),
					result  => q(鲸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯧)),
					result  => q(鲳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯤)),
					result  => q(鲲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯢)),
					result  => q(鲵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯡)),
					result  => q(鲱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯝)),
					result  => q(鲴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯛)),
					result  => q(鲷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯖)),
					result  => q(鲭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯕)),
					result  => q(鲯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯔)),
					result  => q(鲻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯒)),
					result  => q(鲬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯊)),
					result  => q(鲨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯉)),
					result  => q(鲤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯇)),
					result  => q(鲩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯁)),
					result  => q(鲠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鯀)),
					result  => q(鲧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮺)),
					result  => q(鲝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮶)),
					result  => q(鲪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮳)),
					result  => q(鲓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮮)),
					result  => q(鲜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮭)),
					result  => q(鲑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮫)),
					result  => q(鲛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮪)),
					result  => q(鲔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮦)),
					result  => q(鲖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮞)),
					result  => q(鲕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮜)),
					result  => q(鲘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮚)),
					result  => q(鲒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮓)),
					result  => q(鲊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮒)),
					result  => q(鲋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮑)),
					result  => q(鲍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮐)),
					result  => q(鲐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮍)),
					result  => q(鲏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮋)),
					result  => q(鲉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮊)),
					result  => q(鲌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮃)),
					result  => q(鲆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮁)),
					result  => q(鲅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:魺)),
					result  => q(鲄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:魷)),
					result  => q(鱿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:魴)),
					result  => q(鲂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:魯)),
					result  => q(鲁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:魨)),
					result  => q(鲀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:魢)),
					result  => q(鱾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:魛)),
					result  => q(鱽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:魚)),
					result  => q(鱼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:魘)),
					result  => q(魇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:魎)),
					result  => q(魉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬮)),
					result  => q(阄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬩)),
					result  => q(阋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬧)),
					result  => q(闹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬢)),
					result  => q(鬓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:髖)),
					result  => q(髋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:髕)),
					result  => q(髌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:體)),
					result  => q(体),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:髏)),
					result  => q(髅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:骯)),
					result  => q(肮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驫)),
					result  => q(骉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驪)),
					result  => q(骊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驦)),
					result  => q(骦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驥)),
					result  => q(骥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驤)),
					result  => q(骧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驢)),
					result  => q(驴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驟)),
					result  => q(骤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驛)),
					result  => q(驿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驚)),
					result  => q(惊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驗)),
					result  => q(验),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驕)),
					result  => q(骄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驏)),
					result  => q(骣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驍)),
					result  => q(骁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驌)),
					result  => q(骕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驊)),
					result  => q(骅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驅)),
					result  => q(驱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驄)),
					result  => q(骢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驃)),
					result  => q(骠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驂)),
					result  => q(骖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驁)),
					result  => q(骜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:驀)),
					result  => q(蓦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騾)),
					result  => q(骡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騸)),
					result  => q(骟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騷)),
					result  => q(骚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騶)),
					result  => q(驺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騰)),
					result  => q(腾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騮)),
					result  => q(骝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騭)),
					result  => q(骘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騫)),
					result  => q(骞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騧)),
					result  => q(䯄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騤)),
					result  => q(骙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騙)),
					result  => q(骗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騖)),
					result  => q(骛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騏)),
					result  => q(骐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騎)),
					result  => q(骑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騍)),
					result  => q(骒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騌)),
					result  => q(骔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騅)),
					result  => q(骓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騂)),
					result  => q(骍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:騁)),
					result  => q(骋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駿)),
					result  => q(骏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駸)),
					result  => q(骎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駱)),
					result  => q(骆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駰)),
					result  => q(骃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駭)),
					result  => q(骇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駢)),
					result  => q(骈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駟)),
					result  => q(驷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駝)),
					result  => q(驼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駛)),
					result  => q(驶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駙)),
					result  => q(驸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駘)),
					result  => q(骀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駕)),
					result  => q(驾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駔)),
					result  => q(驵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駒)),
					result  => q(驹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駑)),
					result  => q(驽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駐)),
					result  => q(驻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駁)),
					result  => q(驳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:馹)),
					result  => q(驲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:馴)),
					result  => q(驯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:馳)),
					result  => q(驰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:馱)),
					result  => q(驮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:馮)),
					result  => q(冯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:馭)),
					result  => q(驭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:馬)),
					result  => q(马),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:饢)),
					result  => q(馕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:饞)),
					result  => q(馋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:饜)),
					result  => q(餍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:饗)),
					result  => q(飨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:饒)),
					result  => q(饶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:饌)),
					result  => q(馔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:饊)),
					result  => q(馓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:饉)),
					result  => q(馑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:饈)),
					result  => q(馐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:饅)),
					result  => q(馒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:饃)),
					result  => q(馍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:饁)),
					result  => q(馌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餿)),
					result  => q(馊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餾)),
					result  => q(馏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餼)),
					result  => q(饩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餺)),
					result  => q(馎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餷)),
					result  => q(馇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餶)),
					result  => q(馉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餳)),
					result  => q(饧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餱)),
					result  => q(糇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:館)),
					result  => q(馆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餡)),
					result  => q(馅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餞)),
					result  => q(饯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餜)),
					result  => q(馃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餛)),
					result  => q(馄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餖)),
					result  => q(饾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餕)),
					result  => q(馂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餓)),
					result  => q(饿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餒)),
					result  => q(馁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餑)),
					result  => q(饽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餏)),
					result  => q(饻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餎)),
					result  => q(饹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餌)),
					result  => q(饵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:養)),
					result  => q(养),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餉)),
					result  => q(饷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餅)),
					result  => q(饼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餄)),
					result  => q(饸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餃)),
					result  => q(饺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飿)),
					result  => q(饳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飾)),
					result  => q(饰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飽)),
					result  => q(饱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飼)),
					result  => q(饲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飴)),
					result  => q(饴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飲)),
					result  => q(饮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飯)),
					result  => q(饭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飭)),
					result  => q(饬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飫)),
					result  => q(饫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飪)),
					result  => q(饪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飩)),
					result  => q(饨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飥)),
					result  => q(饦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飣)),
					result  => q(饤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飠)),
					result  => q(饣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飛)),
					result  => q(飞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飈)),
					result  => q(飚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飆)),
					result  => q(飙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飄)),
					result  => q(飘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飀)),
					result  => q(飗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:颼)),
					result  => q(飕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:颻)),
					result  => q(飖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:颸)),
					result  => q(飔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:颶)),
					result  => q(飓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:颯)),
					result  => q(飒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:颮)),
					result  => q(飑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:颭)),
					result  => q(飐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:風)),
					result  => q(风),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顴)),
					result  => q(颧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顳)),
					result  => q(颞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顱)),
					result  => q(颅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顰)),
					result  => q(颦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顯)),
					result  => q(显),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顬)),
					result  => q(颥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顫)),
					result  => q(颤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顧)),
					result  => q(顾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顥)),
					result  => q(颢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顢)),
					result  => q(颟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:類)),
					result  => q(类),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顛)),
					result  => q(颠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顙)),
					result  => q(颡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顓)),
					result  => q(颛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顒)),
					result  => q(颙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顎)),
					result  => q(颚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:額)),
					result  => q(额),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:題)),
					result  => q(题),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顆)),
					result  => q(颗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頻)),
					result  => q(频),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頸)),
					result  => q(颈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頷)),
					result  => q(颔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頴)),
					result  => q(颕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頲)),
					result  => q(颋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頰)),
					result  => q(颊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頮)),
					result  => q(颒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頭)),
					result  => q(头),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頦)),
					result  => q(颏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頤)),
					result  => q(颐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頡)),
					result  => q(颉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頜)),
					result  => q(颌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:領)),
					result  => q(领),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頗)),
					result  => q(颇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頓)),
					result  => q(顿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頒)),
					result  => q(颁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頑)),
					result  => q(顽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:預)),
					result  => q(预),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頏)),
					result  => q(颃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頎)),
					result  => q(颀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頌)),
					result  => q(颂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頊)),
					result  => q(顼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頇)),
					result  => q(顸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:順)),
					result  => q(顺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:項)),
					result  => q(项),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頃)),
					result  => q(顷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頂)),
					result  => q(顶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頁)),
					result  => q(页),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:響)),
					result  => q(响),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:韻)),
					result  => q(韵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:韞)),
					result  => q(韫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:韜)),
					result  => q(韬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:韙)),
					result  => q(韪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:韓)),
					result  => q(韩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:韍)),
					result  => q(韨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:韌)),
					result  => q(韧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:韋)),
					result  => q(韦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:韉)),
					result  => q(鞯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:韃)),
					result  => q(鞑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鞽)),
					result  => q(鞒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鞏)),
					result  => q(巩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鞀)),
					result  => q(鼗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:靨)),
					result  => q(靥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:靜)),
					result  => q(静),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:靚)),
					result  => q(靓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:靈)),
					result  => q(灵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:靄)),
					result  => q(霭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:靂)),
					result  => q(雳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:霽)),
					result  => q(霁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:霧)),
					result  => q(雾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:霢)),
					result  => q(霡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:電)),
					result  => q(电),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:難)),
					result  => q(难),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:離)),
					result  => q(离),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:雜)),
					result  => q(杂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:雛)),
					result  => q(雏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:雙)),
					result  => q(双),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:雖)),
					result  => q(虽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:雋)),
					result  => q(隽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:隸)),
					result  => q(隶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:隴)),
					result  => q(陇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:隱)),
					result  => q(隐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:險)),
					result  => q(险),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:隨)),
					result  => q(随),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:際)),
					result  => q(际),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:隕)),
					result  => q(陨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:階)),
					result  => q(阶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:隊)),
					result  => q(队),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:隉)),
					result  => q(陧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:陽)),
					result  => q(阳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:陸)),
					result  => q(陆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:陳)),
					result  => q(陈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:陰)),
					result  => q(阴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:陣)),
					result  => q(阵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:陝)),
					result  => q(陕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:陘)),
					result  => q(陉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:阪)),
					result  => q(坂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闥)),
					result  => q(闼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闤)),
					result  => q(阛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闡)),
					result  => q(阐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闠)),
					result  => q(阓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闞)),
					result  => q(阚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闖)),
					result  => q(闯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闕)),
					result  => q(阙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闔)),
					result  => q(阖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闓)),
					result  => q(闿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闒)),
					result  => q(阘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闐)),
					result  => q(阗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闍)),
					result  => q(阇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闌)),
					result  => q(阑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闋)),
					result  => q(阕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闊)),
					result  => q(阔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闈)),
					result  => q(闱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闃)),
					result  => q(阒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閿)),
					result  => q(阌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閾)),
					result  => q(阈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閽)),
					result  => q(阍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閼)),
					result  => q(阏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閻)),
					result  => q(阎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閹)),
					result  => q(阉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閶)),
					result  => q(阊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閭)),
					result  => q(闾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閬)),
					result  => q(阆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閫)),
					result  => q(阃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閩)),
					result  => q(闽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閨)),
					result  => q(闺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閥)),
					result  => q(阀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閣)),
					result  => q(阁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閡)),
					result  => q(阂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閘)),
					result  => q(闸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閔)),
					result  => q(闵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:間)),
					result  => q(间),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閏)),
					result  => q(闰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閎)),
					result  => q(闳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閌)),
					result  => q(闶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:開)),
					result  => q(开),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閉)),
					result  => q(闭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閈)),
					result  => q(闬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閆)),
					result  => q(闫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閃)),
					result  => q(闪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閂)),
					result  => q(闩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:門)),
					result  => q(门),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:長)),
					result  => q(长),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑿)),
					result  => q(凿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑾)),
					result  => q(銮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑽)),
					result  => q(钻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑼)),
					result  => q(锣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑹)),
					result  => q(镩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑷)),
					result  => q(镊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑲)),
					result  => q(镶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑱)),
					result  => q(镵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑰)),
					result  => q(钥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑭)),
					result  => q(镧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑥)),
					result  => q(镥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑣)),
					result  => q(镳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑠)),
					result  => q(铄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑞)),
					result  => q(镴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑕)),
					result  => q(锧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑔)),
					result  => q(镲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑌)),
					result  => q(镔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑊)),
					result  => q(镬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑄)),
					result  => q(铸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐿)),
					result  => q(镱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐺)),
					result  => q(铛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐸)),
					result  => q(铎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐶)),
					result  => q(镮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐵)),
					result  => q(铁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐳)),
					result  => q(镭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐲)),
					result  => q(镯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐮)),
					result  => q(镰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐨)),
					result  => q(镄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐧)),
					result  => q(锏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐦)),
					result  => q(锎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐠)),
					result  => q(镨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐙)),
					result  => q(镫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐔)),
					result  => q(镡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐓)),
					result  => q(镦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐒)),
					result  => q(铹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐐)),
					result  => q(镣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐋)),
					result  => q(铴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐃)),
					result  => q(铙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏹)),
					result  => q(镪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏷)),
					result  => q(镤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏵)),
					result  => q(铧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏰)),
					result  => q(镚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏨)),
					result  => q(錾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏤)),
					result  => q(镂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏢)),
					result  => q(镖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏡)),
					result  => q(镜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏞)),
					result  => q(镛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏝)),
					result  => q(镘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏜)),
					result  => q(镗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏘)),
					result  => q(锵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏗)),
					result  => q(铿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏑)),
					result  => q(镝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏐)),
					result  => q(镠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏍)),
					result  => q(镙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏌)),
					result  => q(镆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏇)),
					result  => q(镟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏃)),
					result  => q(镞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎿)),
					result  => q(镎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎵)),
					result  => q(镓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎳)),
					result  => q(镍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎲)),
					result  => q(镋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎰)),
					result  => q(镒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎮)),
					result  => q(镇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎬)),
					result  => q(镐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎪)),
					result  => q(锼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎩)),
					result  => q(铩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎧)),
					result  => q(铠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎦)),
					result  => q(镏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎣)),
					result  => q(蓥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎢)),
					result  => q(钨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎡)),
					result  => q(镃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎛)),
					result  => q(镈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎘)),
					result  => q(镉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎖)),
					result  => q(锁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎊)),
					result  => q(镑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎇)),
					result  => q(镅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎄)),
					result  => q(锿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎂)),
					result  => q(镁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍺)),
					result  => q(锗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍶)),
					result  => q(锶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍵)),
					result  => q(键),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍰)),
					result  => q(锾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍬)),
					result  => q(锹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍩)),
					result  => q(锘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍥)),
					result  => q(锲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍤)),
					result  => q(锸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍠)),
					result  => q(锽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍛)),
					result  => q(锻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍚)),
					result  => q(钖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍘)),
					result  => q(铡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍔)),
					result  => q(锷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍍)),
					result  => q(镀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍋)),
					result  => q(锅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍈)),
					result  => q(锳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍇)),
					result  => q(锴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍆)),
					result  => q(钔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍃)),
					result  => q(锪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍀)),
					result  => q(锝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錸)),
					result  => q(铼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錳)),
					result  => q(锰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錯)),
					result  => q(错),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錮)),
					result  => q(锢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錫)),
					result  => q(锡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錩)),
					result  => q(锠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錨)),
					result  => q(锚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錦)),
					result  => q(锦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錢)),
					result  => q(钱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錡)),
					result  => q(锜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錠)),
					result  => q(锭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錟)),
					result  => q(锬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錛)),
					result  => q(锛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錚)),
					result  => q(铮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錙)),
					result  => q(锱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錕)),
					result  => q(锟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錒)),
					result  => q(锕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錐)),
					result  => q(锥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錏)),
					result  => q(铔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錈)),
					result  => q(锩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錇)),
					result  => q(锫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錆)),
					result  => q(锖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錁)),
					result  => q(锞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋼)),
					result  => q(钢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋸)),
					result  => q(锯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋶)),
					result  => q(锍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋱)),
					result  => q(铽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋰)),
					result  => q(锂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋯)),
					result  => q(锆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋮)),
					result  => q(铖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋩)),
					result  => q(铓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋨)),
					result  => q(锇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋦)),
					result  => q(锔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋥)),
					result  => q(锃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋤)),
					result  => q(锄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋣)),
					result  => q(铘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋟)),
					result  => q(锓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋝)),
					result  => q(锊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋙)),
					result  => q(铻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋒)),
					result  => q(锋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋏)),
					result  => q(铗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋌)),
					result  => q(铤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋇)),
					result  => q(钡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋅)),
					result  => q(锌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋃)),
					result  => q(锒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銼)),
					result  => q(锉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銻)),
					result  => q(锑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銷)),
					result  => q(销),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銱)),
					result  => q(铞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銬)),
					result  => q(铐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銫)),
					result  => q(铯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銪)),
					result  => q(铕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銩)),
					result  => q(铥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銨)),
					result  => q(铵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銦)),
					result  => q(铟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銥)),
					result  => q(铱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銣)),
					result  => q(铷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銠)),
					result  => q(铑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銜)),
					result  => q(衔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銛)),
					result  => q(铦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銚)),
					result  => q(铫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銘)),
					result  => q(铭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銖)),
					result  => q(铢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銓)),
					result  => q(铨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銑)),
					result  => q(铣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銍)),
					result  => q(铚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銅)),
					result  => q(铜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銃)),
					result  => q(铳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銀)),
					result  => q(银),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉿)),
					result  => q(铪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉻)),
					result  => q(铬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉺)),
					result  => q(铒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉸)),
					result  => q(铰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉶)),
					result  => q(铏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉭)),
					result  => q(钽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉬)),
					result  => q(钼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉦)),
					result  => q(钲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉞)),
					result  => q(钺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉛)),
					result  => q(铅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉚)),
					result  => q(铆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉕)),
					result  => q(钷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉑)),
					result  => q(铂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉍)),
					result  => q(铋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉋)),
					result  => q(铇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉉)),
					result  => q(铉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉈)),
					result  => q(铊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉀)),
					result  => q(钾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈿)),
					result  => q(钿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈾)),
					result  => q(铀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈽)),
					result  => q(钸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈺)),
					result  => q(钰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈹)),
					result  => q(铍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈸)),
					result  => q(钹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈷)),
					result  => q(钴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈴)),
					result  => q(铃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈳)),
					result  => q(钶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈰)),
					result  => q(铈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈮)),
					result  => q(铌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈧)),
					result  => q(钪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈦)),
					result  => q(钛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈥)),
					result  => q(钬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈣)),
					result  => q(钙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈞)),
					result  => q(钧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈕)),
					result  => q(钮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈔)),
					result  => q(钞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈒)),
					result  => q(钑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈑)),
					result  => q(钣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈐)),
					result  => q(钤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈍)),
					result  => q(钝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈉)),
					result  => q(钠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈈)),
					result  => q(钚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈄)),
					result  => q(钭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈃)),
					result  => q(钘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈁)),
					result  => q(钫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈀)),
					result  => q(钯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釺)),
					result  => q(钎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釹)),
					result  => q(钕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釷)),
					result  => q(钍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釵)),
					result  => q(钗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釩)),
					result  => q(钒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釧)),
					result  => q(钏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釤)),
					result  => q(钐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釣)),
					result  => q(钓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:針)),
					result  => q(针),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釙)),
					result  => q(钋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釘)),
					result  => q(钉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釗)),
					result  => q(钊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釕)),
					result  => q(钌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釔)),
					result  => q(钇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釓)),
					result  => q(钆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釒)),
					result  => q(钅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釐)),
					result  => q(厘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釋)),
					result  => q(释),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釅)),
					result  => q(酽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釃)),
					result  => q(酾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釁)),
					result  => q(衅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釀)),
					result  => q(酿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:醱)),
					result  => q(酦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:醬)),
					result  => q(酱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:醫)),
					result  => q(医),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:酈)),
					result  => q(郦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:酇)),
					result  => q(酂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鄺)),
					result  => q(邝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鄶)),
					result  => q(郐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鄴)),
					result  => q(邺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鄲)),
					result  => q(郸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鄰)),
					result  => q(邻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鄭)),
					result  => q(郑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鄧)),
					result  => q(邓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鄖)),
					result  => q(郧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鄔)),
					result  => q(邬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鄒)),
					result  => q(邹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鄉)),
					result  => q(乡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鄆)),
					result  => q(郓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:郵)),
					result  => q(邮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:郟)),
					result  => q(郏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:邐)),
					result  => q(逦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:邏)),
					result  => q(逻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:邊)),
					result  => q(边),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:邇)),
					result  => q(迩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:還)),
					result  => q(还),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:邁)),
					result  => q(迈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遼)),
					result  => q(辽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遺)),
					result  => q(遗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:選)),
					result  => q(选),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遷)),
					result  => q(迁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遲)),
					result  => q(迟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:適)),
					result  => q(适),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遠)),
					result  => q(远),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遞)),
					result  => q(递),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遜)),
					result  => q(逊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遙)),
					result  => q(遥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:違)),
					result  => q(违),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:達)),
					result  => q(达),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:過)),
					result  => q(过),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:運)),
					result  => q(运),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:進)),
					result  => q(进),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:連)),
					result  => q(连),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:這)),
					result  => q(这),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:逕)),
					result  => q(迳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:農)),
					result  => q(农),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:辯)),
					result  => q(辩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:辮)),
					result  => q(辫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:辦)),
					result  => q(办),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:轤)),
					result  => q(轳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:轢)),
					result  => q(轹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:轡)),
					result  => q(辔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:轟)),
					result  => q(轰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:轔)),
					result  => q(辚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:轎)),
					result  => q(轿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:轍)),
					result  => q(辙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:轉)),
					result  => q(转),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:轆)),
					result  => q(辘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:轅)),
					result  => q(辕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:轄)),
					result  => q(辖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:轂)),
					result  => q(毂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:轀)),
					result  => q(辒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輿)),
					result  => q(舆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輾)),
					result  => q(辗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輻)),
					result  => q(辐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輸)),
					result  => q(输),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輳)),
					result  => q(辏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輯)),
					result  => q(辑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輬)),
					result  => q(辌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輪)),
					result  => q(轮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輩)),
					result  => q(辈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輦)),
					result  => q(辇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輥)),
					result  => q(辊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輟)),
					result  => q(辍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輞)),
					result  => q(辋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輝)),
					result  => q(辉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輜)),
					result  => q(辎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輛)),
					result  => q(辆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輕)),
					result  => q(轻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輔)),
					result  => q(辅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輓)),
					result  => q(挽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輒)),
					result  => q(辄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輊)),
					result  => q(轾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:載)),
					result  => q(载),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輈)),
					result  => q(辀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輇)),
					result  => q(辁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輅)),
					result  => q(辂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:較)),
					result  => q(较),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軾)),
					result  => q(轼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軼)),
					result  => q(轶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軻)),
					result  => q(轲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軺)),
					result  => q(轺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軹)),
					result  => q(轵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軸)),
					result  => q(轴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軲)),
					result  => q(轱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軫)),
					result  => q(轸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軤)),
					result  => q(轷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軟)),
					result  => q(软),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軛)),
					result  => q(轭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軔)),
					result  => q(轫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軒)),
					result  => q(轩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軑)),
					result  => q(轪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軍)),
					result  => q(军),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軌)),
					result  => q(轨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軋)),
					result  => q(轧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:車)),
					result  => q(车),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:軀)),
					result  => q(躯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:躪)),
					result  => q(躏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:躦)),
					result  => q(躜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:躥)),
					result  => q(蹿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:躡)),
					result  => q(蹑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:躚)),
					result  => q(跹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:躕)),
					result  => q(蹰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:躓)),
					result  => q(踬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:躒)),
					result  => q(跞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:躑)),
					result  => q(踯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:躍)),
					result  => q(跃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:躋)),
					result  => q(跻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:躊)),
					result  => q(踌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:躉)),
					result  => q(趸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:躂)),
					result  => q(跶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蹺)),
					result  => q(跷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蹤)),
					result  => q(踪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蹣)),
					result  => q(蹒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蹕)),
					result  => q(跸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蹌)),
					result  => q(跄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:踴)),
					result  => q(踊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:踐)),
					result  => q(践),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:趲)),
					result  => q(趱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:趨)),
					result  => q(趋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:趙)),
					result  => q(赵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:趕)),
					result  => q(赶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:赬)),
					result  => q(赪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:贛)),
					result  => q(赣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:贖)),
					result  => q(赎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:贔)),
					result  => q(赑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:贐)),
					result  => q(赆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:贏)),
					result  => q(赢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:贍)),
					result  => q(赡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:贈)),
					result  => q(赠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:贇)),
					result  => q(赟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:贅)),
					result  => q(赘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:贄)),
					result  => q(贽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賾)),
					result  => q(赜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賽)),
					result  => q(赛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:購)),
					result  => q(购),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賻)),
					result  => q(赙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賺)),
					result  => q(赚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賵)),
					result  => q(赗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賴)),
					result  => q(赖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賰)),
					result  => q(䞐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賭)),
					result  => q(赌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賬)),
					result  => q(账),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:質)),
					result  => q(质),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賧)),
					result  => q(赕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賦)),
					result  => q(赋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賤)),
					result  => q(贱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賣)),
					result  => q(卖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賢)),
					result  => q(贤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賡)),
					result  => q(赓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賠)),
					result  => q(赔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賞)),
					result  => q(赏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賜)),
					result  => q(赐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賚)),
					result  => q(赉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賙)),
					result  => q(赒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賕)),
					result  => q(赇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賓)),
					result  => q(宾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賒)),
					result  => q(赊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賑)),
					result  => q(赈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賊)),
					result  => q(贼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賈)),
					result  => q(贾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:資)),
					result  => q(资),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賅)),
					result  => q(赅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賄)),
					result  => q(贿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賃)),
					result  => q(赁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賂)),
					result  => q(赂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賁)),
					result  => q(贲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賀)),
					result  => q(贺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貿)),
					result  => q(贸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貽)),
					result  => q(贻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貼)),
					result  => q(贴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:費)),
					result  => q(费),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貺)),
					result  => q(贶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貸)),
					result  => q(贷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:買)),
					result  => q(买),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貶)),
					result  => q(贬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貴)),
					result  => q(贵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貳)),
					result  => q(贰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貲)),
					result  => q(赀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貰)),
					result  => q(贳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貯)),
					result  => q(贮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:責)),
					result  => q(责),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貫)),
					result  => q(贯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貪)),
					result  => q(贪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:販)),
					result  => q(贩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貨)),
					result  => q(货),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貧)),
					result  => q(贫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貢)),
					result  => q(贡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:財)),
					result  => q(财),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:負)),
					result  => q(负),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貟)),
					result  => q(贠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貞)),
					result  => q(贞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貝)),
					result  => q(贝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貙)),
					result  => q(䝙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貓)),
					result  => q(猫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:豶)),
					result  => q(豮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:豬)),
					result  => q(猪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:豈)),
					result  => q(岂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:讞)),
					result  => q(谳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:讜)),
					result  => q(谠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:讖)),
					result  => q(谶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:讕)),
					result  => q(谰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:讓)),
					result  => q(让),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:讒)),
					result  => q(谗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:讎)),
					result  => q(雠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:變)),
					result  => q(变),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:讀)),
					result  => q(读),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:譽)),
					result  => q(誉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:譸)),
					result  => q(诪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:護)),
					result  => q(护),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:譴)),
					result  => q(谴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:議)),
					result  => q(议),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:譯)),
					result  => q(译),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:譫)),
					result  => q(谵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:譜)),
					result  => q(谱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:譚)),
					result  => q(谭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:譙)),
					result  => q(谯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:識)),
					result  => q(识),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:譖)),
					result  => q(谮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:譏)),
					result  => q(讥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:譎)),
					result  => q(谲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:譅)),
					result  => q(䜧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謾)),
					result  => q(谩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謹)),
					result  => q(谨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謳)),
					result  => q(讴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謬)),
					result  => q(谬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謫)),
					result  => q(谪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謨)),
					result  => q(谟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謝)),
					result  => q(谢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:講)),
					result  => q(讲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謙)),
					result  => q(谦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謗)),
					result  => q(谤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謖)),
					result  => q(谡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謔)),
					result  => q(谑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謐)),
					result  => q(谧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謎)),
					result  => q(谜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謊)),
					result  => q(谎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謅)),
					result  => q(诌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謄)),
					result  => q(誊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謂)),
					result  => q(谓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謁)),
					result  => q(谒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謀)),
					result  => q(谋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諾)),
					result  => q(诺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諼)),
					result  => q(谖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諺)),
					result  => q(谚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諸)),
					result  => q(诸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諷)),
					result  => q(讽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諶)),
					result  => q(谌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諳)),
					result  => q(谙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諱)),
					result  => q(讳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諭)),
					result  => q(谕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諫)),
					result  => q(谏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諧)),
					result  => q(谐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諦)),
					result  => q(谛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諤)),
					result  => q(谔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諢)),
					result  => q(诨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諞)),
					result  => q(谝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諝)),
					result  => q(谞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諜)),
					result  => q(谍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諛)),
					result  => q(谀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諗)),
					result  => q(谂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:論)),
					result  => q(论),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諒)),
					result  => q(谅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諑)),
					result  => q(诼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諏)),
					result  => q(诹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諍)),
					result  => q(诤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:請)),
					result  => q(请),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諉)),
					result  => q(诿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:談)),
					result  => q(谈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諄)),
					result  => q(谆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諂)),
					result  => q(谄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:調)),
					result  => q(调),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誾)),
					result  => q(訚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誼)),
					result  => q(谊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誹)),
					result  => q(诽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誶)),
					result  => q(谇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:課)),
					result  => q(课),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誰)),
					result  => q(谁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誨)),
					result  => q(诲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誦)),
					result  => q(诵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誥)),
					result  => q(诰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誤)),
					result  => q(误),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誣)),
					result  => q(诬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誡)),
					result  => q(诫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誠)),
					result  => q(诚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:語)),
					result  => q(语),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誚)),
					result  => q(诮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誘)),
					result  => q(诱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誕)),
					result  => q(诞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誒)),
					result  => q(诶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誑)),
					result  => q(诳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:認)),
					result  => q(认),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誇)),
					result  => q(夸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誆)),
					result  => q(诓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誅)),
					result  => q(诛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誄)),
					result  => q(诔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詿)),
					result  => q(诖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詼)),
					result  => q(诙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詵)),
					result  => q(诜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詳)),
					result  => q(详),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:該)),
					result  => q(该),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:話)),
					result  => q(话),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詰)),
					result  => q(诘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詮)),
					result  => q(诠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詭)),
					result  => q(诡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詬)),
					result  => q(诟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詫)),
					result  => q(诧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詩)),
					result  => q(诗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:試)),
					result  => q(试),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詣)),
					result  => q(诣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詢)),
					result  => q(询),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詡)),
					result  => q(诩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詛)),
					result  => q(诅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詘)),
					result  => q(诎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詗)),
					result  => q(诇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詖)),
					result  => q(诐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:評)),
					result  => q(评),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詔)),
					result  => q(诏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詒)),
					result  => q(诒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詐)),
					result  => q(诈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詎)),
					result  => q(讵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詆)),
					result  => q(诋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詁)),
					result  => q(诂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:診)),
					result  => q(诊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訶)),
					result  => q(诃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訴)),
					result  => q(诉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:許)),
					result  => q(许),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:設)),
					result  => q(设),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訪)),
					result  => q(访),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訩)),
					result  => q(讻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訥)),
					result  => q(讷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訣)),
					result  => q(诀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訢)),
					result  => q(䜣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訟)),
					result  => q(讼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訝)),
					result  => q(讶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訛)),
					result  => q(讹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:記)),
					result  => q(记),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訖)),
					result  => q(讫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訕)),
					result  => q(讪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訓)),
					result  => q(训),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訒)),
					result  => q(讱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訐)),
					result  => q(讦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:討)),
					result  => q(讨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訌)),
					result  => q(讧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訊)),
					result  => q(讯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:計)),
					result  => q(计),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訃)),
					result  => q(讣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訂)),
					result  => q(订),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:訁)),
					result  => q(讠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:觸)),
					result  => q(触),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:觶)),
					result  => q(觯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:觴)),
					result  => q(觞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:觀)),
					result  => q(观),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:覿)),
					result  => q(觌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:覽)),
					result  => q(览),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:覺)),
					result  => q(觉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:覷)),
					result  => q(觑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:覲)),
					result  => q(觐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:覯)),
					result  => q(觏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:覬)),
					result  => q(觊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:親)),
					result  => q(亲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:覦)),
					result  => q(觎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:覥)),
					result  => q(觍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:覡)),
					result  => q(觋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:覘)),
					result  => q(觇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:視)),
					result  => q(视),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:覓)),
					result  => q(觅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:規)),
					result  => q(规),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:覎)),
					result  => q(觃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:見)),
					result  => q(见),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:襲)),
					result  => q(袭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:襯)),
					result  => q(衬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:襬)),
					result  => q(䙓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:襪)),
					result  => q(袜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:襠)),
					result  => q(裆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:襝)),
					result  => q(裣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:襖)),
					result  => q(袄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:襏)),
					result  => q(袯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:襇)),
					result  => q(裥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:褻)),
					result  => q(亵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:褳)),
					result  => q(裢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:褲)),
					result  => q(裤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:褘)),
					result  => q(袆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:褌)),
					result  => q(裈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裝)),
					result  => q(装),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:補)),
					result  => q(补),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:袞)),
					result  => q(衮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:衛)),
					result  => q(卫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:術)),
					result  => q(术),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蠻)),
					result  => q(蛮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蠶)),
					result  => q(蚕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蠱)),
					result  => q(蛊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蠨)),
					result  => q(蟏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蠣)),
					result  => q(蛎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蠑)),
					result  => q(蝾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蠐)),
					result  => q(蛴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蠆)),
					result  => q(虿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蠅)),
					result  => q(蝇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蟻)),
					result  => q(蚁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蟶)),
					result  => q(蛏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蟲)),
					result  => q(虫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蟯)),
					result  => q(蛲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蟬)),
					result  => q(蝉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蟣)),
					result  => q(虮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蟎)),
					result  => q(螨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蟈)),
					result  => q(蝈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蟄)),
					result  => q(蛰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:螿)),
					result  => q(螀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:螻)),
					result  => q(蝼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:螮)),
					result  => q(䗖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:螞)),
					result  => q(蚂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:螄)),
					result  => q(蛳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蝸)),
					result  => q(蜗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蝦)),
					result  => q(虾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蝟)),
					result  => q(猬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蝕)),
					result  => q(蚀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蜆)),
					result  => q(蚬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蛻)),
					result  => q(蜕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蛺)),
					result  => q(蛱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:虯)),
					result  => q(虬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:虧)),
					result  => q(亏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:號)),
					result  => q(号),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:虜)),
					result  => q(虏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:虛)),
					result  => q(虚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:處)),
					result  => q(处),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:虆)),
					result  => q(蔂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蘿)),
					result  => q(萝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蘺)),
					result  => q(蓠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蘭)),
					result  => q(兰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蘢)),
					result  => q(茏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蘞)),
					result  => q(蔹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蘚)),
					result  => q(藓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蘇)),
					result  => q(苏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蘆)),
					result  => q(芦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蘄)),
					result  => q(蕲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:藺)),
					result  => q(蔺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:藹)),
					result  => q(蔼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:藶)),
					result  => q(苈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:藪)),
					result  => q(薮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:藝)),
					result  => q(艺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:藎)),
					result  => q(荩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:薺)),
					result  => q(荠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:薳)),
					result  => q(䓕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:薩)),
					result  => q(萨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:薦)),
					result  => q(荐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:薟)),
					result  => q(莶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:薘)),
					result  => q(荙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:薔)),
					result  => q(蔷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:薌)),
					result  => q(芗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:薊)),
					result  => q(蓟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:薈)),
					result  => q(荟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:薀)),
					result  => q(蕰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蕷)),
					result  => q(蓣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蕭)),
					result  => q(萧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蕪)),
					result  => q(芜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蕢)),
					result  => q(蒉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蕘)),
					result  => q(荛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蕕)),
					result  => q(莸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蕒)),
					result  => q(荬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蕎)),
					result  => q(荞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蕆)),
					result  => q(蒇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蕁)),
					result  => q(荨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蔭)),
					result  => q(荫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蔦)),
					result  => q(茑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蔥)),
					result  => q(葱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蔣)),
					result  => q(蒋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蔞)),
					result  => q(蒌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蓽)),
					result  => q(荜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蓯)),
					result  => q(苁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蓮)),
					result  => q(莲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蓋)),
					result  => q(盖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蓀)),
					result  => q(荪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蒼)),
					result  => q(苍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蒞)),
					result  => q(莅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蒔)),
					result  => q(莳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:葷)),
					result  => q(荤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:葦)),
					result  => q(苇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:葤)),
					result  => q(荮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:葒)),
					result  => q(荭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:萵)),
					result  => q(莴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:萊)),
					result  => q(莱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:萇)),
					result  => q(苌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:華)),
					result  => q(华),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:莧)),
					result  => q(苋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:莢)),
					result  => q(荚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:莖)),
					result  => q(茎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:莊)),
					result  => q(庄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:荊)),
					result  => q(荆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:茲)),
					result  => q(兹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:苧)),
					result  => q(苎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:芻)),
					result  => q(刍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:艱)),
					result  => q(艰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:艫)),
					result  => q(舻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:艦)),
					result  => q(舰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:艤)),
					result  => q(舣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:艙)),
					result  => q(舱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:舊)),
					result  => q(旧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:舉)),
					result  => q(举),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:興)),
					result  => q(兴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:與)),
					result  => q(与),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:臨)),
					result  => q(临),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:臢)),
					result  => q(臜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:臠)),
					result  => q(脔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:臚)),
					result  => q(胪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:臏)),
					result  => q(膑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:臍)),
					result  => q(脐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:臉)),
					result  => q(脸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:膿)),
					result  => q(脓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:膾)),
					result  => q(脍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:膽)),
					result  => q(胆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:膩)),
					result  => q(腻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:膠)),
					result  => q(胶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:膚)),
					result  => q(肤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:膃)),
					result  => q(腽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:腸)),
					result  => q(肠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:腳)),
					result  => q(脚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:腫)),
					result  => q(肿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:腦)),
					result  => q(脑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:腡)),
					result  => q(脶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:腖)),
					result  => q(胨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:腎)),
					result  => q(肾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:脹)),
					result  => q(胀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:脫)),
					result  => q(脱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:脛)),
					result  => q(胫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:脈)),
					result  => q(脉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:脅)),
					result  => q(胁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:肅)),
					result  => q(肃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:聾)),
					result  => q(聋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:聽)),
					result  => q(听),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:聹)),
					result  => q(聍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:職)),
					result  => q(职),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:聶)),
					result  => q(聂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:聵)),
					result  => q(聩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:聳)),
					result  => q(耸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:聲)),
					result  => q(声),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:聰)),
					result  => q(聪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:聯)),
					result  => q(联),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:聞)),
					result  => q(闻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:聖)),
					result  => q(圣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:耮)),
					result  => q(耢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:耬)),
					result  => q(耧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:翹)),
					result  => q(翘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:習)),
					result  => q(习),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:義)),
					result  => q(义),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:羥)),
					result  => q(羟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:羋)),
					result  => q(芈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:羈)),
					result  => q(羁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:羆)),
					result  => q(罴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:羅)),
					result  => q(罗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:罷)),
					result  => q(罢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:罰)),
					result  => q(罚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:罌)),
					result  => q(罂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:纜)),
					result  => q(缆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:纘)),
					result  => q(缵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:纓)),
					result  => q(缨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:纏)),
					result  => q(缠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:續)),
					result  => q(续),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:纊)),
					result  => q(纩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:纈)),
					result  => q(缬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繿)),
					result  => q(䍀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繾)),
					result  => q(缱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繽)),
					result  => q(缤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繼)),
					result  => q(继),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繹)),
					result  => q(绎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繸)),
					result  => q(䍁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繳)),
					result  => q(缴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繰)),
					result  => q(缲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繯)),
					result  => q(缳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繭)),
					result  => q(茧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繪)),
					result  => q(绘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繩)),
					result  => q(绳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繢)),
					result  => q(缋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繞)),
					result  => q(绕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繚)),
					result  => q(缭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繕)),
					result  => q(缮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:織)),
					result  => q(织),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繒)),
					result  => q(缯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繆)),
					result  => q(缪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繅)),
					result  => q(缫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:績)),
					result  => q(绩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:總)),
					result  => q(总),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縹)),
					result  => q(缥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縶)),
					result  => q(絷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縵)),
					result  => q(缦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縳)),
					result  => q(䌸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縲)),
					result  => q(缧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縱)),
					result  => q(纵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縮)),
					result  => q(缩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縭)),
					result  => q(缡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縫)),
					result  => q(缝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縣)),
					result  => q(县),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縟)),
					result  => q(缛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縞)),
					result  => q(缟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縝)),
					result  => q(缜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縛)),
					result  => q(缚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縗)),
					result  => q(缞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縕)),
					result  => q(缊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縑)),
					result  => q(缣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縋)),
					result  => q(缒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縊)),
					result  => q(缢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縉)),
					result  => q(缙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縈)),
					result  => q(萦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緹)),
					result  => q(缇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緶)),
					result  => q(缏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緲)),
					result  => q(缈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緱)),
					result  => q(缑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緯)),
					result  => q(纬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緬)),
					result  => q(缅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緩)),
					result  => q(缓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:編)),
					result  => q(编),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緦)),
					result  => q(缌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緣)),
					result  => q(缘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緡)),
					result  => q(缗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:締)),
					result  => q(缔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緞)),
					result  => q(缎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緝)),
					result  => q(缉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緙)),
					result  => q(缂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緘)),
					result  => q(缄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緗)),
					result  => q(缃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緓)),
					result  => q(绬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緒)),
					result  => q(绪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緋)),
					result  => q(绯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緊)),
					result  => q(紧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緇)),
					result  => q(缁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緄)),
					result  => q(绲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綿)),
					result  => q(绵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綾)),
					result  => q(绫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綽)),
					result  => q(绰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綻)),
					result  => q(绽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綺)),
					result  => q(绮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綹)),
					result  => q(绺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綸)),
					result  => q(纶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綴)),
					result  => q(缀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:網)),
					result  => q(网),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綱)),
					result  => q(纲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綰)),
					result  => q(绾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綯)),
					result  => q(绹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:維)),
					result  => q(维),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綬)),
					result  => q(绶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綣)),
					result  => q(绻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綢)),
					result  => q(绸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綞)),
					result  => q(缍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綜)),
					result  => q(综),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:經)),
					result  => q(经),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綐)),
					result  => q(䌼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綏)),
					result  => q(绥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綌)),
					result  => q(绤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綈)),
					result  => q(绨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綆)),
					result  => q(绠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綃)),
					result  => q(绡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綁)),
					result  => q(绑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絹)),
					result  => q(绢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絳)),
					result  => q(绛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絲)),
					result  => q(丝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:統)),
					result  => q(统),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絰)),
					result  => q(绖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絨)),
					result  => q(绒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:給)),
					result  => q(给),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絢)),
					result  => q(绚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絡)),
					result  => q(络),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絞)),
					result  => q(绞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:結)),
					result  => q(结),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絎)),
					result  => q(绗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絆)),
					result  => q(绊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絅)),
					result  => q(䌹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:組)),
					result  => q(组),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:終)),
					result  => q(终),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絀)),
					result  => q(绌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紿)),
					result  => q(绐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紼)),
					result  => q(绋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紺)),
					result  => q(绀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紹)),
					result  => q(绍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紵)),
					result  => q(纻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紳)),
					result  => q(绅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紲)),
					result  => q(绁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紱)),
					result  => q(绂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:細)),
					result  => q(细),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紬)),
					result  => q(䌷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紡)),
					result  => q(纺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紝)),
					result  => q(纴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紜)),
					result  => q(纭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紛)),
					result  => q(纷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:級)),
					result  => q(级),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紙)),
					result  => q(纸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紘)),
					result  => q(纮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紗)),
					result  => q(纱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紖)),
					result  => q(纼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紕)),
					result  => q(纰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:純)),
					result  => q(纯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紓)),
					result  => q(纾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紐)),
					result  => q(纽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:納)),
					result  => q(纳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紋)),
					result  => q(纹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紉)),
					result  => q(纫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紈)),
					result  => q(纨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紇)),
					result  => q(纥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紆)),
					result  => q(纡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紅)),
					result  => q(红),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:約)),
					result  => q(约),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紂)),
					result  => q(纣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紀)),
					result  => q(纪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:糾)),
					result  => q(纠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:糹)),
					result  => q(纟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:糶)),
					result  => q(粜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:糴)),
					result  => q(籴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:糲)),
					result  => q(粝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:糧)),
					result  => q(粮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:糞)),
					result  => q(粪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:糝)),
					result  => q(糁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:粵)),
					result  => q(粤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籮)),
					result  => q(箩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籬)),
					result  => q(篱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籪)),
					result  => q(簖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籩)),
					result  => q(笾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籠)),
					result  => q(笼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籟)),
					result  => q(籁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籜)),
					result  => q(箨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籙)),
					result  => q(箓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籌)),
					result  => q(筹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籃)),
					result  => q(篮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:簾)),
					result  => q(帘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:簹)),
					result  => q(筜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:簫)),
					result  => q(箫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:簣)),
					result  => q(篑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:簡)),
					result  => q(简),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:簞)),
					result  => q(箪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:簍)),
					result  => q(篓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:簀)),
					result  => q(箦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:篳)),
					result  => q(筚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:篩)),
					result  => q(筛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:篤)),
					result  => q(笃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:篔)),
					result  => q(筼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:篋)),
					result  => q(箧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:築)),
					result  => q(筑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:範)),
					result  => q(范),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:節)),
					result  => q(节),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:箏)),
					result  => q(筝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:筴)),
					result  => q(䇲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:筧)),
					result  => q(笕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:筍)),
					result  => q(笋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:筆)),
					result  => q(笔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:競)),
					result  => q(竞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:竊)),
					result  => q(窃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:竇)),
					result  => q(窦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:竅)),
					result  => q(窍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:竄)),
					result  => q(窜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:窺)),
					result  => q(窥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:窶)),
					result  => q(窭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:窵)),
					result  => q(窎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:窯)),
					result  => q(窑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:窮)),
					result  => q(穷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:窪)),
					result  => q(洼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:窩)),
					result  => q(窝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穭)),
					result  => q(稆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穩)),
					result  => q(稳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穢)),
					result  => q(秽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穡)),
					result  => q(穑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穠)),
					result  => q(秾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穎)),
					result  => q(颖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:積)),
					result  => q(积),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穌)),
					result  => q(稣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:稱)),
					result  => q(称),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:稟)),
					result  => q(禀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:稏)),
					result  => q(䅉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:稅)),
					result  => q(税),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:秈)),
					result  => q(籼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:禿)),
					result  => q(秃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:禱)),
					result  => q(祷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:禰)),
					result  => q(祢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:禮)),
					result  => q(礼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:禪)),
					result  => q(禅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:禡)),
					result  => q(祃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:禕)),
					result  => q(祎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:禎)),
					result  => q(祯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:禍)),
					result  => q(祸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:祿)),
					result  => q(禄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:礱)),
					result  => q(砻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:礬)),
					result  => q(矾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:礫)),
					result  => q(砾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:礪)),
					result  => q(砺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:礦)),
					result  => q(矿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:礙)),
					result  => q(碍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:礎)),
					result  => q(础),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:磽)),
					result  => q(硗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:磯)),
					result  => q(矶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:磧)),
					result  => q(碛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:磣)),
					result  => q(碜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:磚)),
					result  => q(砖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:磑)),
					result  => q(硙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:碼)),
					result  => q(码),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:確)),
					result  => q(确),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:碸)),
					result  => q(砜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:碭)),
					result  => q(砀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:碩)),
					result  => q(硕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:硯)),
					result  => q(砚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:硨)),
					result  => q(砗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:硤)),
					result  => q(硖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:硜)),
					result  => q(硁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:矯)),
					result  => q(矫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:矚)),
					result  => q(瞩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:矓)),
					result  => q(眬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瞼)),
					result  => q(睑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瞶)),
					result  => q(瞆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瞞)),
					result  => q(瞒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瞜)),
					result  => q(䁖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瞘)),
					result  => q(眍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:睞)),
					result  => q(睐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:睜)),
					result  => q(睁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:盧)),
					result  => q(卢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:盤)),
					result  => q(盘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:監)),
					result  => q(监),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:盞)),
					result  => q(盏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:盜)),
					result  => q(盗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:皺)),
					result  => q(皱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:皸)),
					result  => q(皲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:皰)),
					result  => q(疱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:皚)),
					result  => q(皑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癲)),
					result  => q(癫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癱)),
					result  => q(瘫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癰)),
					result  => q(痈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癮)),
					result  => q(瘾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癭)),
					result  => q(瘿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癬)),
					result  => q(癣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癩)),
					result  => q(癞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癧)),
					result  => q(疬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癤)),
					result  => q(疖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癢)),
					result  => q(痒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癟)),
					result  => q(瘪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癘)),
					result  => q(疠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癉)),
					result  => q(瘅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癇)),
					result  => q(痫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癆)),
					result  => q(痨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:療)),
					result  => q(疗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瘲)),
					result  => q(疭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瘮)),
					result  => q(瘆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瘧)),
					result  => q(疟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瘡)),
					result  => q(疮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瘞)),
					result  => q(瘗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瘓)),
					result  => q(痪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瘍)),
					result  => q(疡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瘋)),
					result  => q(疯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瘂)),
					result  => q(痖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:痾)),
					result  => q(疴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:痙)),
					result  => q(痉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:疇)),
					result  => q(畴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:異)),
					result  => q(异),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:畢)),
					result  => q(毕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:畝)),
					result  => q(亩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:甌)),
					result  => q(瓯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瓚)),
					result  => q(瓒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瓔)),
					result  => q(璎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瓏)),
					result  => q(珑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:璽)),
					result  => q(玺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:環)),
					result  => q(环),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:璫)),
					result  => q(珰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:璦)),
					result  => q(瑷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:璣)),
					result  => q(玑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:璉)),
					result  => q(琏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瑲)),
					result  => q(玱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瑪)),
					result  => q(玛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瑩)),
					result  => q(莹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瑤)),
					result  => q(瑶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瑣)),
					result  => q(琐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瑒)),
					result  => q(玚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瑋)),
					result  => q(玮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:琿)),
					result  => q(珲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:琺)),
					result  => q(珐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:現)),
					result  => q(现),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:玀)),
					result  => q(猡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獼)),
					result  => q(猕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獻)),
					result  => q(献),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獺)),
					result  => q(獭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獸)),
					result  => q(兽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獷)),
					result  => q(犷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獵)),
					result  => q(猎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獱)),
					result  => q(㺍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獰)),
					result  => q(狞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獮)),
					result  => q(狝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獫)),
					result  => q(猃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獪)),
					result  => q(狯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獨)),
					result  => q(独),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獅)),
					result  => q(狮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獄)),
					result  => q(狱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獁)),
					result  => q(犸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:猻)),
					result  => q(狲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:猶)),
					result  => q(犹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:猙)),
					result  => q(狰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:狽)),
					result  => q(狈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:狹)),
					result  => q(狭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:狀)),
					result  => q(状),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:犧)),
					result  => q(牺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:犢)),
					result  => q(犊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:犖)),
					result  => q(荦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:牽)),
					result  => q(牵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:牘)),
					result  => q(牍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:爾)),
					result  => q(尔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:爺)),
					result  => q(爷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:爭)),
					result  => q(争),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:爛)),
					result  => q(烂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:爐)),
					result  => q(炉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:爍)),
					result  => q(烁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燾)),
					result  => q(焘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燼)),
					result  => q(烬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燶)),
					result  => q(㶶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燴)),
					result  => q(烩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燭)),
					result  => q(烛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燦)),
					result  => q(灿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:營)),
					result  => q(营),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燜)),
					result  => q(焖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燙)),
					result  => q(烫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燒)),
					result  => q(烧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燉)),
					result  => q(炖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燈)),
					result  => q(灯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燁)),
					result  => q(烨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:熾)),
					result  => q(炽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:熲)),
					result  => q(颎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:熱)),
					result  => q(热),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:熗)),
					result  => q(炝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:熅)),
					result  => q(煴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:煱)),
					result  => q(㶽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:煬)),
					result  => q(炀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:煩)),
					result  => q(烦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:煥)),
					result  => q(焕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:煢)),
					result  => q(茕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:煒)),
					result  => q(炜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:無)),
					result  => q(无),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:烴)),
					result  => q(烃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:烏)),
					result  => q(乌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:災)),
					result  => q(灾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:灧)),
					result  => q(滟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:灤)),
					result  => q(滦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:灣)),
					result  => q(湾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:灠)),
					result  => q(漤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:灝)),
					result  => q(灏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:灘)),
					result  => q(滩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:灕)),
					result  => q(漓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:灑)),
					result  => q(洒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:灄)),
					result  => q(滠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:灃)),
					result  => q(沣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀾)),
					result  => q(澜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀲)),
					result  => q(潋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀨)),
					result  => q(濑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀧)),
					result  => q(泷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀦)),
					result  => q(潴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀠)),
					result  => q(潆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀟)),
					result  => q(潇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀝)),
					result  => q(沥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀘)),
					result  => q(泸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀕)),
					result  => q(濒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀏)),
					result  => q(浏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀉)),
					result  => q(泻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀇)),
					result  => q(㲿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀆)),
					result  => q(渎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀅)),
					result  => q(滢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:濾)),
					result  => q(滤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:濼)),
					result  => q(泺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:濺)),
					result  => q(溅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:濱)),
					result  => q(滨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:濰)),
					result  => q(潍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:濫)),
					result  => q(滥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:濤)),
					result  => q(涛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:濟)),
					result  => q(济),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:濘)),
					result  => q(泞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:濃)),
					result  => q(浓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:濁)),
					result  => q(浊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:澮)),
					result  => q(浍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:澩)),
					result  => q(泶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:澦)),
					result  => q(滪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:澤)),
					result  => q(泽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:澠)),
					result  => q(渑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:澗)),
					result  => q(涧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:澇)),
					result  => q(涝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:澆)),
					result  => q(浇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:澀)),
					result  => q(涩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:潿)),
					result  => q(涠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:潷)),
					result  => q(滗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:潰)),
					result  => q(溃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:潯)),
					result  => q(浔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:潤)),
					result  => q(润),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:潛)),
					result  => q(潜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:潔)),
					result  => q(洁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:潑)),
					result  => q(泼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:潁)),
					result  => q(颍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:漿)),
					result  => q(浆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:漸)),
					result  => q(渐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:漵)),
					result  => q(溆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:漲)),
					result  => q(涨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:漬)),
					result  => q(渍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:漣)),
					result  => q(涟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:漢)),
					result  => q(汉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:漚)),
					result  => q(沤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:漁)),
					result  => q(渔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:滿)),
					result  => q(满),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:滾)),
					result  => q(滚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:滻)),
					result  => q(浐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:滸)),
					result  => q(浒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:滲)),
					result  => q(渗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:滯)),
					result  => q(滞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:滬)),
					result  => q(沪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:滎)),
					result  => q(荥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:滌)),
					result  => q(涤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:滅)),
					result  => q(灭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:滄)),
					result  => q(沧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:溫)),
					result  => q(温),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:溝)),
					result  => q(沟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:湯)),
					result  => q(汤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:湞)),
					result  => q(浈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:湊)),
					result  => q(凑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:渾)),
					result  => q(浑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:測)),
					result  => q(测),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:渦)),
					result  => q(涡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:減)),
					result  => q(减),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:渙)),
					result  => q(涣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:淺)),
					result  => q(浅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:淶)),
					result  => q(涞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:淵)),
					result  => q(渊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:淪)),
					result  => q(沦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:淥)),
					result  => q(渌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:淚)),
					result  => q(泪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:涼)),
					result  => q(凉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:淒)),
					result  => q(凄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:涇)),
					result  => q(泾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:浹)),
					result  => q(浃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:洶)),
					result  => q(汹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:況)),
					result  => q(况),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沒)),
					result  => q(没),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:決)),
					result  => q(决),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:祕)),
					result  => q(秘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:浮沈)),
					result  => q(浮沉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:深沈)),
					result  => q(深沉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:消沈)),
					result  => q(消沉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:低沈)),
					result  => q(低沉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈沒)),
					result  => q(沉没),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈著)),
					result  => q(沉着),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈積)),
					result  => q(沉积),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈吟)),
					result  => q(沉吟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈淪)),
					result  => q(沉沦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈潛)),
					result  => q(沉潜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈睡)),
					result  => q(沉睡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈落)),
					result  => q(沉落),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈沈)),
					result  => q(沉沉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈入)),
					result  => q(沉入),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈寂)),
					result  => q(沉寂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈迷)),
					result  => q(沉迷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈醉)),
					result  => q(沉醉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈靜)),
					result  => q(沉静),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈悶)),
					result  => q(沉闷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈浸)),
					result  => q(沉浸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈穩)),
					result  => q(沉稳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈澱)),
					result  => q(沉淀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈思)),
					result  => q(沉思),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈重)),
					result  => q(沉重),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈默)),
					result  => q(沉默),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈浮)),
					result  => q(沉浮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈沈浮浮)),
					result  => q(沉沉浮浮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:破釜沈舟)),
					result  => q(破釜沉舟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:魚沈雁杳)),
					result  => q(鱼沉雁杳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:石沈大海)),
					result  => q(石沉大海),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:墨瀋未乾)),
					result  => q(墨渖未干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀋)),
					result  => q(沈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遼瀋)),
					result  => q(辽沈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:京瀋)),
					result  => q(京沈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀋哈)),
					result  => q(沈哈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀋陽)),
					result  => q(沈阳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀋山線)),
					result  => q(沈山线),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀋山鐵路)),
					result  => q(沈山铁路),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀋山高速)),
					result  => q(沈山高速),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀋吉線)),
					result  => q(沈吉线),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀋吉高速)),
					result  => q(沈吉高速),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀋吉鐵路)),
					result  => q(沈吉铁路),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀋大線)),
					result  => q(沈大线),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀋大高速)),
					result  => q(沈大高速),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀋大鐵路)),
					result  => q(沈大铁路),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:憂)),
					result  => q(忧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬱)),
					result  => q(郁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:積鬱)),
					result  => q(积郁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:抑鬱)),
					result  => q(抑郁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:悒鬱)),
					result  => q(悒郁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:憂鬱)),
					result  => q(忧郁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蒼鬱)),
					result  => q(苍郁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沈鬱)),
					result  => q(沉郁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:陰鬱)),
					result  => q(阴郁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬱鬱)),
					result  => q(郁郁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬱悶)),
					result  => q(郁闷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬱金香)),
					result  => q(郁金香),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:氳)),
					result  => q(氲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:氬)),
					result  => q(氩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:氫)),
					result  => q(氢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:氌)),
					result  => q(氇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:氈)),
					result  => q(毡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:氂)),
					result  => q(牦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:毿)),
					result  => q(毵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:毆)),
					result  => q(殴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:殺)),
					result  => q(杀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:殲)),
					result  => q(歼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:殰)),
					result  => q(㱩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:殯)),
					result  => q(殡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:殮)),
					result  => q(殓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:殫)),
					result  => q(殚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:殨)),
					result  => q(㱮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:殤)),
					result  => q(殇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:殞)),
					result  => q(殒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:殘)),
					result  => q(残),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:歿)),
					result  => q(殁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:歸)),
					result  => q(归),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:歲)),
					result  => q(岁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:歡)),
					result  => q(欢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:歟)),
					result  => q(欤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:歐)),
					result  => q(欧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:欽)),
					result  => q(钦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:欖)),
					result  => q(榄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:欒)),
					result  => q(栾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:欏)),
					result  => q(椤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:權)),
					result  => q(权),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:欄)),
					result  => q(栏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫻)),
					result  => q(樱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫸)),
					result  => q(榉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫳)),
					result  => q(栊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫱)),
					result  => q(蘖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫬)),
					result  => q(榇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫫)),
					result  => q(橥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫪)),
					result  => q(枥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫨)),
					result  => q(栌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫧)),
					result  => q(槠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫥)),
					result  => q(橱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫟)),
					result  => q(栎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫞)),
					result  => q(橼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫝)),
					result  => q(椟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫛)),
					result  => q(栉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫚)),
					result  => q(榈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫓)),
					result  => q(橹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:檻)),
					result  => q(槛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:檸)),
					result  => q(柠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:檳)),
					result  => q(槟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:檮)),
					result  => q(梼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:檣)),
					result  => q(樯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:檢)),
					result  => q(检),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:檟)),
					result  => q(槚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:檜)),
					result  => q(桧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:檔)),
					result  => q(档),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:檉)),
					result  => q(柽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:檁)),
					result  => q(檩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:橫)),
					result  => q(横),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:橢)),
					result  => q(椭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:橋)),
					result  => q(桥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:橈)),
					result  => q(桡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:樺)),
					result  => q(桦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:樹)),
					result  => q(树),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:樣)),
					result  => q(样),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:樞)),
					result  => q(枢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:樓)),
					result  => q(楼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:樅)),
					result  => q(枞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:樂)),
					result  => q(乐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:樁)),
					result  => q(桩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:槳)),
					result  => q(桨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:槨)),
					result  => q(椁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:槧)),
					result  => q(椠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:槤)),
					result  => q(梿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:榿)),
					result  => q(桤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:榲)),
					result  => q(榅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:榮)),
					result  => q(荣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:榪)),
					result  => q(杩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:業)),
					result  => q(业),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:楨)),
					result  => q(桢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:楓)),
					result  => q(枫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:楊)),
					result  => q(杨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:椏)),
					result  => q(桠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:棶)),
					result  => q(梾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:棲)),
					result  => q(栖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:棧)),
					result  => q(栈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:棟)),
					result  => q(栋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:棗)),
					result  => q(枣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:棖)),
					result  => q(枨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:棄)),
					result  => q(弃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:梲)),
					result  => q(棁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:梟)),
					result  => q(枭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:條)),
					result  => q(条),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:梘)),
					result  => q(枧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:梔)),
					result  => q(栀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:桿)),
					result  => q(杆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:柵)),
					result  => q(栅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:東)),
					result  => q(东),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:會)),
					result  => q(会),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:書)),
					result  => q(书),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:曬)),
					result  => q(晒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:曨)),
					result  => q(昽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:曠)),
					result  => q(旷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:曖)),
					result  => q(暧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:曉)),
					result  => q(晓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:曇)),
					result  => q(昙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:曄)),
					result  => q(晔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:暫)),
					result  => q(暂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:暢)),
					result  => q(畅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:暘)),
					result  => q(旸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:暉)),
					result  => q(晖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:暈)),
					result  => q(晕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:晝)),
					result  => q(昼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:晉)),
					result  => q(晋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:時)),
					result  => q(时),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:斷)),
					result  => q(断),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:斬)),
					result  => q(斩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:斕)),
					result  => q(斓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:斃)),
					result  => q(毙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:數)),
					result  => q(数),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:敵)),
					result  => q(敌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:敘)),
					result  => q(叙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:敗)),
					result  => q(败),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:攬)),
					result  => q(揽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:攪)),
					result  => q(搅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:攤)),
					result  => q(摊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:攣)),
					result  => q(挛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:攢)),
					result  => q(攒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:攝)),
					result  => q(摄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:攜)),
					result  => q(携),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:攛)),
					result  => q(撺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:攙)),
					result  => q(搀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:攖)),
					result  => q(撄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:攔)),
					result  => q(拦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:攏)),
					result  => q(拢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:攆)),
					result  => q(撵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:攄)),
					result  => q(摅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擾)),
					result  => q(扰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擼)),
					result  => q(撸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擻)),
					result  => q(擞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擺)),
					result  => q(摆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擷)),
					result  => q(撷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擴)),
					result  => q(扩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擲)),
					result  => q(掷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擱)),
					result  => q(搁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擰)),
					result  => q(拧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擯)),
					result  => q(摈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擬)),
					result  => q(拟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擠)),
					result  => q(挤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:據)),
					result  => q(据),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擔)),
					result  => q(担),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擓)),
					result  => q(㧟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擋)),
					result  => q(挡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擊)),
					result  => q(击),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擇)),
					result  => q(择),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擄)),
					result  => q(掳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擁)),
					result  => q(拥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撿)),
					result  => q(捡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撾)),
					result  => q(挝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撻)),
					result  => q(挞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撳)),
					result  => q(揿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撲)),
					result  => q(扑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撫)),
					result  => q(抚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撥)),
					result  => q(拨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撟)),
					result  => q(挢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撝)),
					result  => q(㧑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撓)),
					result  => q(挠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撐)),
					result  => q(撑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撏)),
					result  => q(挦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撈)),
					result  => q(捞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:摻)),
					result  => q(掺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:摶)),
					result  => q(抟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:摳)),
					result  => q(抠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:摯)),
					result  => q(挚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:摟)),
					result  => q(搂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:摜)),
					result  => q(掼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:摑)),
					result  => q(掴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:搶)),
					result  => q(抢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:搵)),
					result  => q(揾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:搖)),
					result  => q(摇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:損)),
					result  => q(损),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:揮)),
					result  => q(挥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:換)),
					result  => q(换),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:揀)),
					result  => q(拣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:掙)),
					result  => q(挣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:掗)),
					result  => q(挜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:掄)),
					result  => q(抡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:掃)),
					result  => q(扫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捫)),
					result  => q(扪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:挾)),
					result  => q(挟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:挩)),
					result  => q(捝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:拋)),
					result  => q(抛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:戶)),
					result  => q(户),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:戲)),
					result  => q(戏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:戱)),
					result  => q(戯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:戰)),
					result  => q(战),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:戩)),
					result  => q(戬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:戧)),
					result  => q(戗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:戔)),
					result  => q(戋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:戇)),
					result  => q(戆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:戀)),
					result  => q(恋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懾)),
					result  => q(慑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懼)),
					result  => q(惧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懺)),
					result  => q(忏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懸)),
					result  => q(悬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懷)),
					result  => q(怀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懶)),
					result  => q(懒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懲)),
					result  => q(惩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懨)),
					result  => q(恹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懣)),
					result  => q(懑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懟)),
					result  => q(怼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懍)),
					result  => q(懔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懌)),
					result  => q(怿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:應)),
					result  => q(应),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懇)),
					result  => q(恳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:憶)),
					result  => q(忆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:憲)),
					result  => q(宪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:憮)),
					result  => q(怃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:憫)),
					result  => q(悯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:憤)),
					result  => q(愤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:憚)),
					result  => q(惮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:憒)),
					result  => q(愦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:憑)),
					result  => q(凭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:憐)),
					result  => q(怜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:憊)),
					result  => q(惫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慶)),
					result  => q(庆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慳)),
					result  => q(悭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慮)),
					result  => q(虑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慫)),
					result  => q(怂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慪)),
					result  => q(怄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慣)),
					result  => q(惯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慟)),
					result  => q(恸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慚)),
					result  => q(惭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慘)),
					result  => q(惨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慍)),
					result  => q(愠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:態)),
					result  => q(态),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:愾)),
					result  => q(忾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:愷)),
					result  => q(恺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:愴)),
					result  => q(怆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:愜)),
					result  => q(惬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:愛)),
					result  => q(爱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:惻)),
					result  => q(恻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:惲)),
					result  => q(恽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:惱)),
					result  => q(恼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:惡)),
					result  => q(恶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:悶)),
					result  => q(闷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:悵)),
					result  => q(怅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:悞)),
					result  => q(悮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:悅)),
					result  => q(悦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:恆)),
					result  => q(恒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:徹)),
					result  => q(彻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:徠)),
					result  => q(徕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:從)),
					result  => q(从),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:徑)),
					result  => q(径),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:彥)),
					result  => q(彦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:彎)),
					result  => q(弯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:彈)),
					result  => q(弹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:強)),
					result  => q(强),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:張)),
					result  => q(张),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:弳)),
					result  => q(弪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:弒)),
					result  => q(弑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:廳)),
					result  => q(厅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:廬)),
					result  => q(庐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:廩)),
					result  => q(廪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:廣)),
					result  => q(广),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:廢)),
					result  => q(废),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:廡)),
					result  => q(庑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:廠)),
					result  => q(厂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:廟)),
					result  => q(庙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:廝)),
					result  => q(厮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:廚)),
					result  => q(厨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:廈)),
					result  => q(厦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:廄)),
					result  => q(厩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:廂)),
					result  => q(厢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:庫)),
					result  => q(库),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幬)),
					result  => q(帱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幫)),
					result  => q(帮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幣)),
					result  => q(币),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幟)),
					result  => q(帜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幘)),
					result  => q(帻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幗)),
					result  => q(帼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幃)),
					result  => q(帏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幀)),
					result  => q(帧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:帶)),
					result  => q(带),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:帳)),
					result  => q(帐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:師)),
					result  => q(师),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:帥)),
					result  => q(帅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:巰)),
					result  => q(巯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:巔)),
					result  => q(巅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:巒)),
					result  => q(峦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:巋)),
					result  => q(岿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嶼)),
					result  => q(屿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嶺)),
					result  => q(岭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嶸)),
					result  => q(嵘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嶴)),
					result  => q(岙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嶮)),
					result  => q(崄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嶧)),
					result  => q(峄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嶢)),
					result  => q(峣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嶠)),
					result  => q(峤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嶗)),
					result  => q(崂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嶔)),
					result  => q(嵚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嶇)),
					result  => q(岖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嶄)),
					result  => q(崭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嶁)),
					result  => q(嵝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嵐)),
					result  => q(岚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:崬)),
					result  => q(岽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:崢)),
					result  => q(峥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:崗)),
					result  => q(岗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:崍)),
					result  => q(崃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:峽)),
					result  => q(峡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:島)),
					result  => q(岛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:峴)),
					result  => q(岘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:岡)),
					result  => q(冈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:屬)),
					result  => q(属),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:屨)),
					result  => q(屦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:層)),
					result  => q(层),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:屢)),
					result  => q(屡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:屜)),
					result  => q(屉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:屓)),
					result  => q(屃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:屍)),
					result  => q(尸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:屆)),
					result  => q(届),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:尷)),
					result  => q(尴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:導)),
					result  => q(导),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:對)),
					result  => q(对),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:尋)),
					result  => q(寻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:專)),
					result  => q(专),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:將)),
					result  => q(将),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:寶)),
					result  => q(宝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:寵)),
					result  => q(宠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:寬)),
					result  => q(宽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:寫)),
					result  => q(写),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:審)),
					result  => q(审),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:寧)),
					result  => q(宁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:實)),
					result  => q(实),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:寢)),
					result  => q(寝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:宮)),
					result  => q(宫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:孿)),
					result  => q(孪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:學)),
					result  => q(学),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:孫)),
					result  => q(孙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:孌)),
					result  => q(娈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嬸)),
					result  => q(婶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嬰)),
					result  => q(婴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嬪)),
					result  => q(嫔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嬤)),
					result  => q(嬷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嬡)),
					result  => q(嫒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嬙)),
					result  => q(嫱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嬌)),
					result  => q(娇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嬋)),
					result  => q(婵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嬈)),
					result  => q(娆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嫿)),
					result  => q(婳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嫻)),
					result  => q(娴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嫵)),
					result  => q(妩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嫗)),
					result  => q(妪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:媽)),
					result  => q(妈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:媼)),
					result  => q(媪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:媧)),
					result  => q(娲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:婭)),
					result  => q(娅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:婦)),
					result  => q(妇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:婁)),
					result  => q(娄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:娛)),
					result  => q(娱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:姍)),
					result  => q(姗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:奼)),
					result  => q(姹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:奮)),
					result  => q(奋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:奪)),
					result  => q(夺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:奩)),
					result  => q(奁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:奧)),
					result  => q(奥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:奐)),
					result  => q(奂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:夾)),
					result  => q(夹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:夢)),
					result  => q(梦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:夠)),
					result  => q(够),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壽)),
					result  => q(寿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壼)),
					result  => q(壸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壺)),
					result  => q(壶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壯)),
					result  => q(壮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壩)),
					result  => q(坝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壢)),
					result  => q(坜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壠)),
					result  => q(垅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壟)),
					result  => q(垄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壞)),
					result  => q(坏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壚)),
					result  => q(垆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壙)),
					result  => q(圹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壘)),
					result  => q(垒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壓)),
					result  => q(压),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壋)),
					result  => q(垱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:墾)),
					result  => q(垦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:墳)),
					result  => q(坟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:墮)),
					result  => q(堕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:墜)),
					result  => q(坠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:墊)),
					result  => q(垫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:塹)),
					result  => q(堑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:塵)),
					result  => q(尘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:塢)),
					result  => q(坞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:塗)),
					result  => q(涂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:塒)),
					result  => q(埘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:塏)),
					result  => q(垲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:塋)),
					result  => q(茔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:塊)),
					result  => q(块),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:場)),
					result  => q(场),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:報)),
					result  => q(报),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:堯)),
					result  => q(尧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:堝)),
					result  => q(埚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:堖)),
					result  => q(垴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:堊)),
					result  => q(垩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:堅)),
					result  => q(坚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:執)),
					result  => q(执),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:埡)),
					result  => q(垭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:垵)),
					result  => q(埯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:圖)),
					result  => q(图),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:圓)),
					result  => q(圆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:園)),
					result  => q(园),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:圍)),
					result  => q(围),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:國)),
					result  => q(国),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:圇)),
					result  => q(囵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:囪)),
					result  => q(囱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:囑)),
					result  => q(嘱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:囈)),
					result  => q(呓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:囅)),
					result  => q(冁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:囂)),
					result  => q(嚣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:囁)),
					result  => q(嗫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:囀)),
					result  => q(啭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚶)),
					result  => q(嘤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚴)),
					result  => q(严),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚳)),
					result  => q(喾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚲)),
					result  => q(亸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚨)),
					result  => q(咙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚦)),
					result  => q(呖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚕)),
					result  => q(噜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚌)),
					result  => q(哜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚇)),
					result  => q(吓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚀)),
					result  => q(咛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:噸)),
					result  => q(吨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:噴)),
					result  => q(喷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:噲)),
					result  => q(哙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:噯)),
					result  => q(嗳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:噦)),
					result  => q(哕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:噥)),
					result  => q(哝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:噠)),
					result  => q(哒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:噝)),
					result  => q(咝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:噚)),
					result  => q(㖊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:噓)),
					result  => q(嘘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嘽)),
					result  => q(啴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嘸)),
					result  => q(呒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嘵)),
					result  => q(哓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嘰)),
					result  => q(叽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嘯)),
					result  => q(啸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嘮)),
					result  => q(唠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嘜)),
					result  => q(唛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嘖)),
					result  => q(啧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嘔)),
					result  => q(呕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嘍)),
					result  => q(喽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嗶)),
					result  => q(哔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嗩)),
					result  => q(唢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嗚)),
					result  => q(呜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嗎)),
					result  => q(吗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嗊)),
					result  => q(唝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嗇)),
					result  => q(啬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嗆)),
					result  => q(呛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:喲)),
					result  => q(哟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:單)),
					result  => q(单),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:喬)),
					result  => q(乔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:喪)),
					result  => q(丧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:喚)),
					result  => q(唤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:喎)),
					result  => q(㖞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:啢)),
					result  => q(唡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:啞)),
					result  => q(哑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:問)),
					result  => q(问),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:唄)),
					result  => q(呗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:員)),
					result  => q(员),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:咼)),
					result  => q(呙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:呂)),
					result  => q(吕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:吶)),
					result  => q(呐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:吳)),
					result  => q(吴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:吒)),
					result  => q(咤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:叢)),
					result  => q(丛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:叄)),
					result  => q(叁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:參)),
					result  => q(参),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:厴)),
					result  => q(厣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:厲)),
					result  => q(厉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:厭)),
					result  => q(厌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:厙)),
					result  => q(厍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:卻)),
					result  => q(却),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:協)),
					result  => q(协),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:區)),
					result  => q(区),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:匱)),
					result  => q(匮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:匭)),
					result  => q(匦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:勻)),
					result  => q(匀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:勸)),
					result  => q(劝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:勵)),
					result  => q(励),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:勱)),
					result  => q(劢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:勩)),
					result  => q(勚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:勢)),
					result  => q(势),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:勞)),
					result  => q(劳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:勝)),
					result  => q(胜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:務)),
					result  => q(务),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:動)),
					result  => q(动),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:勁)),
					result  => q(劲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劚)),
					result  => q(㔉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劑)),
					result  => q(剂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劏)),
					result  => q(㓥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劍)),
					result  => q(剑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劌)),
					result  => q(刿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劊)),
					result  => q(刽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劉)),
					result  => q(刘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劇)),
					result  => q(剧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:創)),
					result  => q(创),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:剴)),
					result  => q(剀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:剮)),
					result  => q(剐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:剝)),
					result  => q(剥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:剛)),
					result  => q(刚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:剗)),
					result  => q(刬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:剎)),
					result  => q(刹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:則)),
					result  => q(则),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:剄)),
					result  => q(刭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:刪)),
					result  => q(删),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:凱)),
					result  => q(凯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:凜)),
					result  => q(凛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:凍)),
					result  => q(冻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:冪)),
					result  => q(幂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:冊)),
					result  => q(册),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:兩)),
					result  => q(两),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:內)),
					result  => q(内),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:兗)),
					result  => q(兖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:兒)),
					result  => q(儿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:兌)),
					result  => q(兑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:豐)),
					result  => q(丰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:儼)),
					result  => q(俨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:儺)),
					result  => q(傩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:儸)),
					result  => q(㑩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:儷)),
					result  => q(俪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:儲)),
					result  => q(储),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:優)),
					result  => q(优),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:償)),
					result  => q(偿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:儕)),
					result  => q(侪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:儔)),
					result  => q(俦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:儐)),
					result  => q(傧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:儉)),
					result  => q(俭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:儈)),
					result  => q(侩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:億)),
					result  => q(亿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:儂)),
					result  => q(侬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:儀)),
					result  => q(仪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:價)),
					result  => q(价),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:僨)),
					result  => q(偾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:僕)),
					result  => q(仆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:僑)),
					result  => q(侨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:僉)),
					result  => q(佥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:僅)),
					result  => q(仅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:僂)),
					result  => q(偻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:傾)),
					result  => q(倾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:傷)),
					result  => q(伤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:債)),
					result  => q(债),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:傴)),
					result  => q(伛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:傳)),
					result  => q(传),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:傯)),
					result  => q(偬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:傭)),
					result  => q(佣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:備)),
					result  => q(备),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:傘)),
					result  => q(伞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:傖)),
					result  => q(伧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:傑)),
					result  => q(杰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:偵)),
					result  => q(侦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:側)),
					result  => q(侧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:偉)),
					result  => q(伟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:倫)),
					result  => q(伦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:們)),
					result  => q(们),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:倉)),
					result  => q(仓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:倈)),
					result  => q(俫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:倆)),
					result  => q(俩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:倀)),
					result  => q(伥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:俠)),
					result  => q(侠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:俔)),
					result  => q(伣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:俁)),
					result  => q(俣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:侶)),
					result  => q(侣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:來)),
					result  => q(来),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:佇)),
					result  => q(伫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:臥)),
					result  => q(卧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:亞)),
					result  => q(亚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:亂)),
					result  => q(乱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:丟)),
					result  => q(丢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:䲁)),
					result  => q(鳚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:䰾)),
					result  => q(鲃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:䱽)),
					result  => q(䲝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:䯀)),
					result  => q(䯅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:䝼)),
					result  => q(䞍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:䋻)),
					result  => q(䌾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:䋙)),
					result  => q(䌺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:䊷)),
					result  => q(䌶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:㩜)),
					result  => q(㨫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:㠏)),
					result  => q(㟆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮎)),
					result  => q(鲇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:礆)),
					result  => q(硷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:倘)),
					result  => q(倘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:儻)),
					result  => q(傥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:和)),
					result  => q(和),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:妒)),
					result  => q(妒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:種)),
					result  => q(种),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷀)),
					result  => q(鹚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮝)),
					result  => q(鲞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蒓)),
					result  => q(莼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瓊)),
					result  => q(琼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詠)),
					result  => q(咏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍁)),
					result  => q(锨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:極)),
					result  => q(极),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋁)),
					result  => q(铝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:亙)),
					result  => q(亘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:於)),
					result  => q(于),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎸)),
					result  => q(镌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐫)),
					result  => q(镌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:彞)),
					result  => q(彝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:睪)),
					result  => q(睾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:箎)),
					result  => q(篪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鼈)),
					result  => q(鳖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱉)),
					result  => q(鳖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:隄)),
					result  => q(堤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:阨)),
					result  => q(厄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎗)),
					result  => q(枪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:槍)),
					result  => q(枪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:踰)),
					result  => q(逾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:踡)),
					result  => q(蜷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蠧)),
					result  => q(蠹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:翺)),
					result  => q(翱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餚)),
					result  => q(肴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:菜餚)),
					result  => q(菜肴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餚饌)),
					result  => q(肴馔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:酒餚)),
					result  => q(酒肴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:佳餚)),
					result  => q(佳肴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:積餚於案)),
					result  => q(积肴于案),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:罣)),
					result  => q(挂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:掛)),
					result  => q(挂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:罣礙)),
					result  => q(挂碍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蹧)),
					result  => q(糟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:褸)),
					result  => q(褛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:襤)),
					result  => q(褴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縷)),
					result  => q(缕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:藍)),
					result  => q(蓝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諡)),
					result  => q(谥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謚)),
					result  => q(谥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:囍)),
					result  => q(禧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:痀)),
					result  => q(佝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蔴)),
					result  => q(麻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瑯)),
					result  => q(琅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:琺瑯)),
					result  => q(珐琅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鼇)),
					result  => q(鳌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰲)),
					result  => q(鳌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:皁)),
					result  => q(皂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賸)),
					result  => q(剩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:檝)),
					result  => q(楫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:轝)),
					result  => q(舆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:搨)),
					result  => q(拓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:構)),
					result  => q(构),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:搆)),
					result  => q(构),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:搆和)),
					result  => q(媾和),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壎)),
					result  => q(埙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:塤)),
					result  => q(埙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餬)),
					result  => q(糊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:歛)),
					result  => q(敛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:斂)),
					result  => q(敛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:怵目)),
					result  => q(触目),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:搥)),
					result  => q(捶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:靷)),
					result  => q(纼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:槖)),
					result  => q(橐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:咷)),
					result  => q(啕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:喨)),
					result  => q(亮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:唸)),
					result  => q(念),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:囓)),
					result  => q(啮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齧)),
					result  => q(啮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚙)),
					result  => q(啮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:卹)),
					result  => q(恤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:卹養)),
					result  => q(恤养),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撫卹)),
					result  => q(抚恤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:僇)),
					result  => q(戮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:依杖)),
					result  => q(依仗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:彿)),
					result  => q(佛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:倣)),
					result  => q(仿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:仿)),
					result  => q(仿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:彷彿)),
					result  => q(仿佛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:近傍)),
					result  => q(近旁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:彷如)),
					result  => q(仿如),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:徬)),
					result  => q(彷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:依徬)),
					result  => q(依傍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:佛佗)),
					result  => q(佛陀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瞇)),
					result  => q(眯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:倡言)),
					result  => q(昌言),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:枒)),
					result  => q(丫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:洩)),
					result  => q(泄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:排泄)),
					result  => q(排泄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:醃)),
					result  => q(腌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:勗)),
					result  => q(勖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:孃)),
					result  => q(娘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:摀)),
					result  => q(捂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餵)),
					result  => q(喂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:棱)),
					result  => q(棱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:稜)),
					result  => q(棱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懮)),
					result  => q(忧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:毬)),
					result  => q(球),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蠍)),
					result  => q(蝎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:羶)),
					result  => q(膻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:礡)),
					result  => q(礴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:悽)),
					result  => q(凄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:簷)),
					result  => q(檐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燐)),
					result  => q(磷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籐)),
					result  => q(藤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釦)),
					result  => q(扣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沍)),
					result  => q(冱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:份子)),
					result  => q(分子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬨)),
					result  => q(哄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閧)),
					result  => q(哄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:譟)),
					result  => q(噪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鼓譟)),
					result  => q(鼓噪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:名譟一時)),
					result  => q(名噪一时),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:甕)),
					result  => q(瓮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蓆)),
					result  => q(席),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:暱)),
					result  => q(昵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燿)),
					result  => q(耀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:塚)),
					result  => q(冢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:韁)),
					result  => q(缰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繮)),
					result  => q(缰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:諮)),
					result  => q(谘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懃)),
					result  => q(勤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慇)),
					result  => q(殷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀰)),
					result  => q(弥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:彌)),
					result  => q(弥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瀰漫)),
					result  => q(弥漫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繇役)),
					result  => q(徭役),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:羨)),
					result  => q(羡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:翫)),
					result  => q(玩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:烟)),
					result  => q(烟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:菸)),
					result  => q(烟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:煙)),
					result  => q(烟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燻)),
					result  => q(熏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:煙薰)),
					result  => q(烟熏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:碳煙)),
					result  => q(炭烟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:剷)),
					result  => q(铲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏟)),
					result  => q(铲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:濬)),
					result  => q(浚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:疏濬)),
					result  => q(疏浚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:叮叮噹噹)),
					result  => q(叮叮当当),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:叮噹)),
					result  => q(叮当),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籲)),
					result  => q(吁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籲防)),
					result  => q(吁防),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籲請)),
					result  => q(吁请),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籲求)),
					result  => q(吁求),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:呼籲)),
					result  => q(呼吁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫺)),
					result  => q(棂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:欞)),
					result  => q(棂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癒)),
					result  => q(愈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:治癒)),
					result  => q(治愈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:痊癒)),
					result  => q(痊愈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:病癒)),
					result  => q(病愈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癒復)),
					result  => q(愈复),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:療癒)),
					result  => q(疗愈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:固疾痊癒)),
					result  => q(固疾痊愈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:不藥而癒)),
					result  => q(不药而愈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:久病不癒)),
					result  => q(久病不愈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撢)),
					result  => q(掸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撣)),
					result  => q(掸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:巖)),
					result  => q(岩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑿通巖洞)),
					result  => q(凿通岩洞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑿巖成室)),
					result  => q(凿岩成室),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:巖穴)),
					result  => q(岩穴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:峭壁巉巖)),
					result  => q(峭壁巉岩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:奇巖)),
					result  => q(奇岩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:岱嶽)),
					result  => q(岱岳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:中嶽)),
					result  => q(中岳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:山嶽)),
					result  => q(山岳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:北嶽)),
					result  => q(北岳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:西嶽)),
					result  => q(西岳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:南嶽)),
					result  => q(南岳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:東嶽)),
					result  => q(东岳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:五嶽)),
					result  => q(五岳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縐)),
					result  => q(绉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:摺)),
					result  => q(折),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:摺紙)),
					result  => q(折纸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:皺摺)),
					result  => q(皱褶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縐摺)),
					result  => q(绉褶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絝)),
					result  => q(绔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:袴)),
					result  => q(绔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:痠)),
					result  => q(酸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:衊)),
					result  => q(蔑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:搾)),
					result  => q(榨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:藷)),
					result  => q(薯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:纔)),
					result  => q(才),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:贊)),
					result  => q(赞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:讚)),
					result  => q(赞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蝨)),
					result  => q(虱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:虱目魚)),
					result  => q(虱目鱼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燬)),
					result  => q(毁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:毀)),
					result  => q(毁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:像片)),
					result  => q(相片),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:搧)),
					result  => q(扇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:砂土)),
					result  => q(沙土),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:砂金)),
					result  => q(沙金),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎔)),
					result  => q(镕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎔鑄)),
					result  => q(熔铸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎔銷)),
					result  => q(熔销),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎔融)),
					result  => q(熔融),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎔劑)),
					result  => q(熔剂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎔爐)),
					result  => q(熔炉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:箝)),
					result  => q(钳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉗)),
					result  => q(钳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撚)),
					result  => q(捻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:疊)),
					result  => q(叠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:褶紙)),
					result  => q(折纸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:褶疊)),
					result  => q(折叠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慼)),
					result  => q(戚),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嬝)),
					result  => q(袅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嫋)),
					result  => q(袅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裊)),
					result  => q(袅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:囉)),
					result  => q(啰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綑)),
					result  => q(捆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉅)),
					result  => q(钜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:跼)),
					result  => q(局),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:侷)),
					result  => q(局),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:局)),
					result  => q(局),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:溼)),
					result  => q(湿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:濕)),
					result  => q(湿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:盃)),
					result  => q(杯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑑)),
					result  => q(鉴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鑒)),
					result  => q(鉴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:私)),
					result  => q(私),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:俬)),
					result  => q(私),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:俱)),
					result  => q(具),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:具)),
					result  => q(具),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:樑)),
					result  => q(梁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:梁)),
					result  => q(梁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餽)),
					result  => q(馈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:饋)),
					result  => q(馈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銲)),
					result  => q(焊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:焊)),
					result  => q(焊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:譁)),
					result  => q(哗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嘩)),
					result  => q(哗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絃)),
					result  => q(弦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:箇)),
					result  => q(个),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:個)),
					result  => q(个),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:汙)),
					result  => q(污),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:污)),
					result  => q(污),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:姊)),
					result  => q(姐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:姐)),
					result  => q(姐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遯)),
					result  => q(遁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遁)),
					result  => q(遁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:殼)),
					result  => q(壳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:脣)),
					result  => q(唇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:唇)),
					result  => q(唇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:舖)),
					result  => q(铺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋪)),
					result  => q(铺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:喫)),
					result  => q(吃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:吃)),
					result  => q(吃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚐)),
					result  => q(尝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嘗)),
					result  => q(尝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:証)),
					result  => q(证),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:證)),
					result  => q(证),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闇)),
					result  => q(暗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:豔)),
					result  => q(艳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:艷)),
					result  => q(艳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:黴)),
					result  => q(霉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:霉)),
					result  => q(霉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:螢)),
					result  => q(萤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:熒)),
					result  => q(荧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:螢屏)),
					result  => q(荧屏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:螢幕)),
					result  => q(荧幕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:螢光)),
					result  => q(荧光),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:細察)),
					result  => q(细查),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詢察)),
					result  => q(询查),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:稽察)),
					result  => q(稽查),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:巡察)),
					result  => q(巡查),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏈)),
					result  => q(链),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:練)),
					result  => q(练),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:煉)),
					result  => q(炼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍊)),
					result  => q(炼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:項鍊)),
					result  => q(项链),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐵鍊)),
					result  => q(铁链),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:手鍊)),
					result  => q(手链),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:拉鍊)),
					result  => q(拉链),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍊子)),
					result  => q(链子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:金鍊)),
					result  => q(金链),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:洗鍊)),
					result  => q(洗练),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍊氣)),
					result  => q(练气),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:磨鍊)),
					result  => q(磨练),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎚)),
					result  => q(锤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錘)),
					result  => q(锤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捶鍊)),
					result  => q(锤炼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錘鍊)),
					result  => q(锤炼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍛鍊)),
					result  => q(锻炼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:焠鍊)),
					result  => q(淬炼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍊句)),
					result  => q(炼句),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍊銅)),
					result  => q(炼铜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍊鋁)),
					result  => q(炼铝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:百鍊)),
					result  => q(百炼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:千錘百鍊)),
					result  => q(千锤百炼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:久鍊成鋼)),
					result  => q(久炼成钢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍊而愈精)),
					result  => q(炼而愈精),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍊石補天)),
					result  => q(炼石补天),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籤)),
					result  => q(签),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:簽)),
					result  => q(签),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:中籤)),
					result  => q(中签),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籤譜)),
					result  => q(签谱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:解籤)),
					result  => q(解签),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:萬)),
					result  => q(万),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:萬籤插架)),
					result  => q(万签插架),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:芸)),
					result  => q(芸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蕓)),
					result  => q(芸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:芸籤縹帶)),
					result  => q(芸签缥带),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:竹籤)),
					result  => q(竹签),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:求籤)),
					result  => q(求签),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籤語)),
					result  => q(签语),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籤文)),
					result  => q(签文),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籤筒)),
					result  => q(签筒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籤條)),
					result  => q(签条),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籤詩)),
					result  => q(签诗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:抽籤)),
					result  => q(抽签),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蒐)),
					result  => q(搜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:搜)),
					result  => q(搜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蒐錄)),
					result  => q(搜录),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蒐集)),
					result  => q(搜集),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蒐羅)),
					result  => q(搜罗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:朗朗乾坤)),
					result  => q(朗朗乾坤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:旋乾轉坤)),
					result  => q(旋乾转坤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:扭轉乾坤)),
					result  => q(扭转乾坤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:着)),
					result  => q(着),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:著)),
					result  => q(着),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:拙著)),
					result  => q(拙著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:撰著)),
					result  => q(撰著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:專著)),
					result  => q(专著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:原著)),
					result  => q(原著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:譯著)),
					result  => q(译著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遺著)),
					result  => q(遗著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:玄著)),
					result  => q(玄著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:新著)),
					result  => q(新著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:土著)),
					result  => q(土著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:卓著)),
					result  => q(卓著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:暴著)),
					result  => q(暴著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:名著)),
					result  => q(名著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:毛著)),
					result  => q(毛著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:舊著)),
					result  => q(旧著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:較著)),
					result  => q(较著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉅著)),
					result  => q(钜著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:巨著)),
					result  => q(巨著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:合著)),
					result  => q(合著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:大著)),
					result  => q(大著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:昭著)),
					result  => q(昭著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:炳著)),
					result  => q(炳著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:編著)),
					result  => q(编著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:論著)),
					result  => q(论著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顯著)),
					result  => q(显著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:信義素著)),
					result  => q(信义素著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:見微知著)),
					result  => q(见微知著),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:著者)),
					result  => q(著者),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:著有)),
					result  => q(著有),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:著文)),
					result  => q(著文),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:著錄)),
					result  => q(著录),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:著績)),
					result  => q(著绩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:著書)),
					result  => q(著书),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:著作)),
					result  => q(著作),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:著述)),
					result  => q(著述),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:著稱)),
					result  => q(著称),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:著名)),
					result  => q(著名),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:霑)),
					result  => q(沾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:霑醉)),
					result  => q(沾醉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:霑衣)),
					result  => q(沾衣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:霑渥)),
					result  => q(沾渥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:霑濡)),
					result  => q(沾濡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:霑霈)),
					result  => q(沾霈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:霑恩)),
					result  => q(沾恩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍾)),
					result  => q(钟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐘)),
					result  => q(钟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍾山)),
					result  => q(钟山),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍾馗)),
					result  => q(钟馗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍾愛)),
					result  => q(钟爱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍾離)),
					result  => q(钟离),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:所鍾)),
					result  => q(所钟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:漢鍾離)),
					result  => q(汉钟离),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獨鍾)),
					result  => q(独钟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:龍鍾)),
					result  => q(龙钟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:千鍾粟)),
					result  => q(千钟粟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:一見鍾情)),
					result  => q(一见钟情),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鍾靈毓秀)),
					result  => q(钟灵毓秀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:朴)),
					result  => q(朴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:樸)),
					result  => q(朴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:朴硝)),
					result  => q(朴硝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:朴刀)),
					result  => q(朴刀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:厚朴)),
					result  => q(厚朴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縴)),
					result  => q(纤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:纖)),
					result  => q(纤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縴繩)),
					result  => q(纤绳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縴路)),
					result  => q(纤路),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縴夫)),
					result  => q(纤夫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:拉縴)),
					result  => q(拉纤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:櫃)),
					result  => q(柜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:柜柳)),
					result  => q(柜柳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蚝)),
					result  => q(蚝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蠔)),
					result  => q(蚝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:倖)),
					result  => q(幸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幸)),
					result  => q(幸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:僥)),
					result  => q(侥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:僥倖)),
					result  => q(侥幸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:凈)),
					result  => q(净),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:淨)),
					result  => q(净),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蹟)),
					result  => q(迹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:跡)),
					result  => q(迹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:史蹟)),
					result  => q(史迹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:古蹟)),
					result  => q(古迹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:愿)),
					result  => q(愿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:願)),
					result  => q(愿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鄉愿)),
					result  => q(乡愿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:臘)),
					result  => q(腊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:方腊)),
					result  => q(方腊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:英吋)),
					result  => q(英寸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:弔)),
					result  => q(吊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:吊)),
					result  => q(吊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:弔唁)),
					result  => q(吊唁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:弔慰)),
					result  => q(吊慰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:弔喪)),
					result  => q(吊丧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:提心弔膽)),
					result  => q(提心吊胆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:形影相弔)),
					result  => q(形影相吊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:弔民伐罪)),
					result  => q(吊民伐罪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚥)),
					result  => q(咽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:咽)),
					result  => q(咽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:下嚥)),
					result  => q(下咽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚥氣)),
					result  => q(咽气),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:狼吞虎嚥)),
					result  => q(狼吞虎咽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:細嚼慢嚥)),
					result  => q(细嚼慢咽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慄)),
					result  => q(栗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:栗)),
					result  => q(栗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:戰慄)),
					result  => q(战栗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顫慄)),
					result  => q(颤栗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:不寒而慄)),
					result  => q(不寒而栗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:秋)),
					result  => q(秋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:盪)),
					result  => q(荡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蕩)),
					result  => q(荡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:盪鞦韆)),
					result  => q(荡秋千),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鞦韆)),
					result  => q(秋千),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:勛)),
					result  => q(勋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:勳)),
					result  => q(勋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:姪)),
					result  => q(侄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:侄)),
					result  => q(侄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:姪孫)),
					result  => q(侄孙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:姪女)),
					result  => q(侄女),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:姪媳婦)),
					result  => q(侄媳妇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:跤)),
					result  => q(交),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:交)),
					result  => q(交),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:跌跤)),
					result  => q(跌交),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:貍)),
					result  => q(狸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:狸)),
					result  => q(狸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:颳)),
					result  => q(刮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:刮)),
					result  => q(刮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:颳倒)),
					result  => q(刮倒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:僱)),
					result  => q(雇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:雇)),
					result  => q(雇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:僱員)),
					result  => q(雇员),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:杠)),
					result  => q(杠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:槓)),
					result  => q(杠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:舍)),
					result  => q(舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捨)),
					result  => q(舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:豬舍)),
					result  => q(猪舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:農舍)),
					result  => q(农舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:房舍)),
					result  => q(房舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:老舍)),
					result  => q(老舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:茅舍)),
					result  => q(茅舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:民舍)),
					result  => q(民舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:校舍)),
					result  => q(校舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:田舍)),
					result  => q(田舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:屋舍)),
					result  => q(屋舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:宿舍)),
					result  => q(宿舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:舍弟)),
					result  => q(舍弟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:舍利)),
					result  => q(舍利),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:左鄰右舍)),
					result  => q(左邻右舍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:睏)),
					result  => q(困),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:困)),
					result  => q(困),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:睏乏)),
					result  => q(困乏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:睏憊)),
					result  => q(困惫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:纍)),
					result  => q(累),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:累)),
					result  => q(累),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:涌)),
					result  => q(涌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:湧)),
					result  => q(涌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:託)),
					result  => q(托),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:托)),
					result  => q(托),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:轉託)),
					result  => q(转托),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:囑託)),
					result  => q(嘱托),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:依託)),
					result  => q(依托),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:受託)),
					result  => q(受托),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:請託)),
					result  => q(请托),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:寄託)),
					result  => q(寄托),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:付託)),
					result  => q(付托),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:拜託)),
					result  => q(拜托),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:委託)),
					result  => q(委托),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:信託)),
					result  => q(信托),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:託收)),
					result  => q(托收),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:託名)),
					result  => q(托名),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:占)),
					result  => q(占),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:佔)),
					result  => q(占),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:占星)),
					result  => q(占星),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:占夢)),
					result  => q(占梦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:占卦)),
					result  => q(占卦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:占卜)),
					result  => q(占卜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紮)),
					result  => q(扎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:扎)),
					result  => q(扎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駐紮)),
					result  => q(驻扎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紮營)),
					result  => q(扎营),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:曏)),
					result  => q(向),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚮)),
					result  => q(向),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:向)),
					result  => q(向),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚮往)),
					result  => q(向往),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚮應)),
					result  => q(响应),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嚮導)),
					result  => q(向导),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:淀)),
					result  => q(淀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:澱)),
					result  => q(淀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:東淀)),
					result  => q(东淀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:海淀)),
					result  => q(海淀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:水淀)),
					result  => q(水淀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:荷花淀)),
					result  => q(荷花淀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:白洋淀)),
					result  => q(白洋淀),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癡)),
					result  => q(痴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:痴)),
					result  => q(痴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癥)),
					result  => q(症),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:症)),
					result  => q(症),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:癥結)),
					result  => q(症结),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錶)),
					result  => q(表),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:表)),
					result  => q(表),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:停錶)),
					result  => q(停表),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:手錶)),
					result  => q(手表),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:跑錶)),
					result  => q(跑表),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐘錶)),
					result  => q(钟表),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:馬錶)),
					result  => q(马表),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:秒錶)),
					result  => q(秒表),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懷錶)),
					result  => q(怀表),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:掛錶)),
					result  => q(挂表),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:夜光錶)),
					result  => q(夜光表),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:馬蹄錶)),
					result  => q(马蹄表),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:防水錶)),
					result  => q(防水表),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:電鍍錶)),
					result  => q(电度表),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:電子錶)),
					result  => q(电子表),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錶針)),
					result  => q(表针),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錶盤)),
					result  => q(表盘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錶鏈)),
					result  => q(表链),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錶帶)),
					result  => q(表带),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錶蒙子)),
					result  => q(表蒙子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊)),
					result  => q(游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:游)),
					result  => q(游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:夜遊)),
					result  => q(夜游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:野遊)),
					result  => q(野游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遨遊)),
					result  => q(遨游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:仙遊)),
					result  => q(仙游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:秋遊)),
					result  => q(秋游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:神遊)),
					result  => q(神游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:浪遊)),
					result  => q(浪游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:旅遊)),
					result  => q(旅游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:環遊)),
					result  => q(环游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:巡遊)),
					result  => q(巡游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嬉遊)),
					result  => q(嬉游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:夢遊)),
					result  => q(梦游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:漫遊)),
					result  => q(漫游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:冶遊)),
					result  => q(冶游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:倦遊)),
					result  => q(倦游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:郊遊)),
					result  => q(郊游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:交遊)),
					result  => q(交游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:導遊)),
					result  => q(导游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:春遊)),
					result  => q(春游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:串遊)),
					result  => q(串游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:暢遊)),
					result  => q(畅游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊學)),
					result  => q(游学),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊醫)),
					result  => q(游医),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊逛)),
					result  => q(游逛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊覽)),
					result  => q(游览),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊行)),
					result  => q(游行),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊藝)),
					result  => q(游艺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊艇)),
					result  => q(游艇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊舫)),
					result  => q(游舫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊興)),
					result  => q(游兴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊遍)),
					result  => q(游遍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊園)),
					result  => q(游园),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊玩)),
					result  => q(游玩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊獵)),
					result  => q(游猎),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊魂)),
					result  => q(游魂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊手)),
					result  => q(游手),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊戲)),
					result  => q(游戏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊閑)),
					result  => q(游闲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊憩)),
					result  => q(游憩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊仙)),
					result  => q(游仙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊說)),
					result  => q(游说),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊蕩)),
					result  => q(游荡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊民)),
					result  => q(游民),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊俠)),
					result  => q(游侠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊子)),
					result  => q(游子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊人)),
					result  => q(游人),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊牧)),
					result  => q(游牧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊廊)),
					result  => q(游廊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊樂)),
					result  => q(游乐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊客)),
					result  => q(游客),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊街)),
					result  => q(游街),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊記)),
					result  => q(游记),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊方)),
					result  => q(游方),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊春)),
					result  => q(游春),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊程)),
					result  => q(游程),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊伴)),
					result  => q(游伴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊山玩水)),
					result  => q(游山玩水),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閑)),
					result  => q(闲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閒)),
					result  => q(闲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閑居)),
					result  => q(闲居),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閑靜)),
					result  => q(闲静),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:粧)),
					result  => q(妆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:妝)),
					result  => q(妆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閲)),
					result  => q(阅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:閱)),
					result  => q(阅),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:钁)),
					result  => q(䦆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鐝)),
					result  => q(镢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銹)),
					result  => q(锈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鏽)),
					result  => q(锈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:録)),
					result  => q(录),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:錄)),
					result  => q(录),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:醞)),
					result  => q(酝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:醖)),
					result  => q(酝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:豎)),
					result  => q(竖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:竪)),
					result  => q(竖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:譾)),
					result  => q(谫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謭)),
					result  => q(谫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謡)),
					result  => q(谣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謠)),
					result  => q(谣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:説)),
					result  => q(说),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:說)),
					result  => q(说),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:藴)),
					result  => q(蕴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蘊)),
					result  => q(蕴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:苹)),
					result  => q(苹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蘋)),
					result  => q(苹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:苎)),
					result  => q(苧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:薴)),
					result  => q(苧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:耻)),
					result  => q(耻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:恥)),
					result  => q(耻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:秆)),
					result  => q(秆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:稈)),
					result  => q(秆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:眦)),
					result  => q(眦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:眥)),
					result  => q(眦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:奬)),
					result  => q(奖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獎)),
					result  => q(奖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:墻)),
					result  => q(墙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:牆)),
					result  => q(墙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:牀)),
					result  => q(床),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:床)),
					result  => q(床),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:氹)),
					result  => q(凼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:凼)),
					result  => q(凼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綳)),
					result  => q(绷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繃)),
					result  => q(绷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緑)),
					result  => q(绿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綠)),
					result  => q(绿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絶)),
					result  => q(绝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絕)),
					result  => q(绝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:竈)),
					result  => q(灶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:灶)),
					result  => q(灶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瘺)),
					result  => q(瘘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瘻)),
					result  => q(瘘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:産)),
					result  => q(产),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:產)),
					result  => q(产),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:爲)),
					result  => q(为),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:為)),
					result  => q(为),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:潙)),
					result  => q(沩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:溈)),
					result  => q(沩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擣)),
					result  => q(捣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:搗)),
					result  => q(捣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:厠)),
					result  => q(厕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:廁)),
					result  => q(厕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:埰)),
					result  => q(采),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:採)),
					result  => q(采),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綵)),
					result  => q(彩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:彩)),
					result  => q(彩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:采緝)),
					result  => q(采缉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:喝采)),
					result  => q(喝采),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:多采)),
					result  => q(多采),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:神采)),
					result  => q(神采),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:精采)),
					result  => q(精采),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:風采)),
					result  => q(风采),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:采風)),
					result  => q(采风),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:無精打采)),
					result  => q(无精打采),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:興高采烈)),
					result  => q(兴高采烈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:采薪之憂)),
					result  => q(采薪之忧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蜡)),
					result  => q(蜡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蠟)),
					result  => q(蜡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:缽)),
					result  => q(钵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉢)),
					result  => q(钵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綉)),
					result  => q(绣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繡)),
					result  => q(绣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:絛)),
					result  => q(绦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縧)),
					result  => q(绦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穫)),
					result  => q(获),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獲)),
					result  => q(获),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:僞)),
					result  => q(伪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:偽)),
					result  => q(伪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:陞)),
					result  => q(升),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:昇)),
					result  => q(升),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:升)),
					result  => q(升),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:歌舞昇平)),
					result  => q(歌舞升平),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:高昇)),
					result  => q(高升),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:畢昇)),
					result  => q(毕升),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:昇華)),
					result  => q(升华),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:罈)),
					result  => q(坛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:罎)),
					result  => q(坛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壜)),
					result  => q(坛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壇)),
					result  => q(坛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:酒罈)),
					result  => q(酒坛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:罈子)),
					result  => q(坛子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:醋罈)),
					result  => q(醋坛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瓶瓶罈罈)),
					result  => q(瓶瓶坛坛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:罈罈罐罐)),
					result  => q(坛坛罐罐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:尅)),
					result  => q(克),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:剋)),
					result  => q(克),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:克)),
					result  => q(克),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慤)),
					result  => q(悫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:愨)),
					result  => q(悫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:悳)),
					result  => q(德),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:德)),
					result  => q(德),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:几)),
					result  => q(几),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幾)),
					result  => q(几),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:茶几)),
					result  => q(茶几),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:啟)),
					result  => q(启),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:啓)),
					result  => q(启),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:礮)),
					result  => q(炮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:砲)),
					result  => q(炮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:炮)),
					result  => q(炮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顔)),
					result  => q(颜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:顏)),
					result  => q(颜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頽)),
					result  => q(颓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頹)),
					result  => q(颓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鷄)),
					result  => q(鸡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬀)),
					result  => q(剃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:剃)),
					result  => q(剃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:歎)),
					result  => q(叹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嘆)),
					result  => q(叹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:羣)),
					result  => q(群),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:群)),
					result  => q(群),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:吢)),
					result  => q(吣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:唚)),
					result  => q(吣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:簆)),
					result  => q(筘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:筘)),
					result  => q(筘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齎)),
					result  => q(赍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:賫)),
					result  => q(赍),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:雞)),
					result  => q(鸡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鳬)),
					result  => q(凫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鳧)),
					result  => q(凫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鱷)),
					result  => q(鳄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鰐)),
					result  => q(鳄),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:髒)),
					result  => q(脏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:臟)),
					result  => q(脏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駡)),
					result  => q(骂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:罵)),
					result  => q(骂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懞)),
					result  => q(蒙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蒙)),
					result  => q(蒙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:朧)),
					result  => q(胧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:欵)),
					result  => q(款),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:款)),
					result  => q(款),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:饑)),
					result  => q(饥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:飢)),
					result  => q(饥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:関)),
					result  => q(关),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:關)),
					result  => q(关),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:麤)),
					result  => q(粗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:粗)),
					result  => q(粗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:贜)),
					result  => q(赃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:贓)),
					result  => q(赃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:贗)),
					result  => q(赝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:贋)),
					result  => q(赝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鋭)),
					result  => q(锐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銳)),
					result  => q(锐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鞝)),
					result  => q(绱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緔)),
					result  => q(绱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鉤)),
					result  => q(钩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鈎)),
					result  => q(钩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:衆)),
					result  => q(众),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:眾)),
					result  => q(众),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嬀)),
					result  => q(妫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:媯)),
					result  => q(妫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:汎)),
					result  => q(泛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:氾)),
					result  => q(泛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:泛)),
					result  => q(泛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獃)),
					result  => q(呆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:呆)),
					result  => q(呆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:滷)),
					result  => q(卤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鹵)),
					result  => q(卤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鹽滷)),
					result  => q(盐卤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:茶滷)),
					result  => q(茶卤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:滷菜)),
					result  => q(卤菜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:滷味)),
					result  => q(卤味),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:滷雞)),
					result  => q(卤鸡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:糰)),
					result  => q(团),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:團)),
					result  => q(团),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:牋)),
					result  => q(笺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:箋)),
					result  => q(笺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:韮)),
					result  => q(韭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:韭)),
					result  => q(韭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:荳)),
					result  => q(豆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:豆)),
					result  => q(豆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:䶧)),
					result  => q(咬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齩)),
					result  => q(咬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:咬)),
					result  => q(咬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:讌)),
					result  => q(䜩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:醼)),
					result  => q(宴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:宴)),
					result  => q(宴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:颺)),
					result  => q(飏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:䬗)),
					result  => q(扬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:揚)),
					result  => q(扬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:兇)),
					result  => q(凶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:凶)),
					result  => q(凶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:逞兇)),
					result  => q(逞凶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:正兇)),
					result  => q(正凶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:元兇)),
					result  => q(元凶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:兇手)),
					result  => q(凶手),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:兇器)),
					result  => q(凶器),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:兇暴)),
					result  => q(凶暴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:註)),
					result  => q(注),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:注)),
					result  => q(注),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:加註)),
					result  => q(加注),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:附註)),
					result  => q(附注),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:評註)),
					result  => q(评注),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:註疏)),
					result  => q(注疏),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:註解)),
					result  => q(注解),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:註銷)),
					result  => q(注销),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:註冊)),
					result  => q(注册),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:標)),
					result  => q(标),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:準)),
					result  => q(准),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:准)),
					result  => q(准),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:對準)),
					result  => q(对准),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:基準)),
					result  => q(基准),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:水準)),
					result  => q(水准),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:標籤)),
					result  => q(标签),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:標準)),
					result  => q(标准),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:為準)),
					result  => q(为准),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:準確)),
					result  => q(准确),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:準備)),
					result  => q(准备),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:準頭)),
					result  => q(准头),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:準時)),
					result  => q(准时),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:準繩)),
					result  => q(准绳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慾)),
					result  => q(欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:欲)),
					result  => q(欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嗜慾)),
					result  => q(嗜欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:六慾)),
					result  => q(六欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:性慾)),
					result  => q(性欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縱慾)),
					result  => q(纵欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:獸慾)),
					result  => q(兽欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:私慾)),
					result  => q(私欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:食慾)),
					result  => q(食欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:色慾)),
					result  => q(色欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:肉慾)),
					result  => q(肉欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:情慾)),
					result  => q(情欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:利慾)),
					result  => q(利欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:禁慾)),
					result  => q(禁欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慾望)),
					result  => q(欲望),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慾火)),
					result  => q(欲火),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:求知慾)),
					result  => q(求知欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:人之大慾)),
					result  => q(人之大欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慾不可縱)),
					result  => q(欲不可纵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:克慾修行)),
					result  => q(克欲修行),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:清心寡慾)),
					result  => q(清心寡欲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鹹)),
					result  => q(咸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:咸)),
					result  => q(咸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鹹菜)),
					result  => q(咸菜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鼕)),
					result  => q(冬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:冬)),
					result  => q(冬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鼕鼕)),
					result  => q(冬冬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:廻)),
					result  => q(回),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:迴)),
					result  => q(回),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:回)),
					result  => q(回),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:迂迴)),
					result  => q(迂回),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縈迴)),
					result  => q(萦回),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:回遊)),
					result  => q(回游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:迴廊)),
					result  => q(回廊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:迴路)),
					result  => q(回路),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:覈)),
					result  => q(核),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:核)),
					result  => q(核),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:覈算)),
					result  => q(核算),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:覈實)),
					result  => q(核实),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:綫)),
					result  => q(线),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:線)),
					result  => q(线),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:齣)),
					result  => q(出),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:出)),
					result  => q(出),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:出遊)),
					result  => q(出游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:冲)),
					result  => q(冲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沖)),
					result  => q(冲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:衝)),
					result  => q(冲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:喜沖沖)),
					result  => q(喜冲冲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沖毀)),
					result  => q(冲毁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沖洗)),
					result  => q(冲洗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沖繩)),
					result  => q(冲绳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沖天)),
					result  => q(冲天),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沖涼)),
					result  => q(冲凉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沖積)),
					result  => q(冲积),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沖服)),
					result  => q(冲服),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沖淡)),
					result  => q(冲淡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沖茶)),
					result  => q(冲茶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蔔)),
					result  => q(卜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:卜)),
					result  => q(卜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蘿蔔)),
					result  => q(萝卜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:丑)),
					result  => q(丑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:醜)),
					result  => q(丑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:小丑)),
					result  => q(小丑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:丑角)),
					result  => q(丑角),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:丑旦)),
					result  => q(丑旦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:丑時)),
					result  => q(丑时),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:生旦净末丑)),
					result  => q(生旦淨末丑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:子丑寅卯)),
					result  => q(子丑寅卯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:云)),
					result  => q(云),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:雲)),
					result  => q(云),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:雲遊)),
					result  => q(云游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:不知所云)),
					result  => q(不知所云),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:人云亦云)),
					result  => q(人云亦云),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲)),
					result  => q(卷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:髮)),
					result  => q(发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:發)),
					result  => q(发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:一髮)),
					result  => q(一发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:剃发)),
					result  => q(剃髮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:秀髮)),
					result  => q(秀发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頭髮)),
					result  => q(头发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:勢頭)),
					result  => q(势头),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燙髮)),
					result  => q(烫发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:散髮)),
					result  => q(散发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:美髮)),
					result  => q(美发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:毛髮)),
					result  => q(毛发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:落髮)),
					result  => q(落发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:理髮)),
					result  => q(理发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲髮)),
					result  => q(卷发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:結髮)),
					result  => q(结发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:假髮)),
					result  => q(假发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:護髮)),
					result  => q(护发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:毫髮)),
					result  => q(毫发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:編髮)),
					result  => q(编发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:染髮)),
					result  => q(染发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:銀髮)),
					result  => q(銀发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紅髮)),
					result  => q(红发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:金髮)),
					result  => q(金发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:黑髮)),
					result  => q(黑发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:白髮)),
					result  => q(白发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:短髮)),
					result  => q(短发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:長髮)),
					result  => q(长发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:怒髮衝冠)),
					result  => q(怒发冲冠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:硃卷)),
					result  => q(朱卷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蛋捲)),
					result  => q(蛋卷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:龍捲風)),
					result  => q(龙卷风),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:風馳電捲)),
					result  => q(风驰电卷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:風捲殘雲)),
					result  => q(风卷残云),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:舒捲)),
					result  => q(舒卷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:席捲)),
					result  => q(席卷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲軸)),
					result  => q(卷轴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:紙捲)),
					result  => q(纸卷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:煙捲)),
					result  => q(烟卷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:春捲)),
					result  => q(春卷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲鬚)),
					result  => q(卷须),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲雲)),
					result  => q(卷云),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲門)),
					result  => q(卷门),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲起)),
					result  => q(卷起),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲走)),
					result  => q(卷走),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲袖)),
					result  => q(卷袖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲舌)),
					result  => q(卷舌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲縮)),
					result  => q(卷缩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲紙)),
					result  => q(卷纸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲簾)),
					result  => q(卷帘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲款)),
					result  => q(卷款),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲曲)),
					result  => q(卷曲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲成)),
					result  => q(卷成),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲動)),
					result  => q(卷动),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲入)),
					result  => q(卷入),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲尺)),
					result  => q(卷尺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲鋪蓋)),
					result  => q(卷铺盖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲心菜)),
					result  => q(卷心菜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:捲土重來)),
					result  => q(卷土重来),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:發睏)),
					result  => q(发困),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:髮型)),
					result  => q(发型),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:髮妻)),
					result  => q(发妻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:髮廊)),
					result  => q(发廊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:机)),
					result  => q(机),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:機)),
					result  => q(机),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詞)),
					result  => q(词),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:辞)),
					result  => q(辞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:辭)),
					result  => q(辞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:彙)),
					result  => q(汇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:匯)),
					result  => q(汇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:字彙)),
					result  => q(字汇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:詞彙)),
					result  => q(词汇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:彙報)),
					result  => q(汇报),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:彆)),
					result  => q(别),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:別)),
					result  => q(别),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:彆扭)),
					result  => q(别扭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誌)),
					result  => q(志),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:志)),
					result  => q(志),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:雜誌)),
					result  => q(杂志),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縣誌)),
					result  => q(县志),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:碑誌)),
					result  => q(碑志),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:日誌)),
					result  => q(日志),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:墓誌)),
					result  => q(墓志),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:標誌)),
					result  => q(标志),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:地方誌)),
					result  => q(地方志),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:后)),
					result  => q(后),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:後)),
					result  => q(后),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:太后)),
					result  => q(太后),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:王后)),
					result  => q(王后),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:母后)),
					result  => q(母后),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:皇后)),
					result  => q(皇后),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:后羿)),
					result  => q(后羿),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:后土)),
					result  => q(后土),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:后稷)),
					result  => q(后稷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:后妃)),
					result  => q(后妃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:榖)),
					result  => q(谷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穀)),
					result  => q(谷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:谷)),
					result  => q(谷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:曬穀)),
					result  => q(晒谷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:秕穀)),
					result  => q(秕谷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:米穀)),
					result  => q(米谷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:五穀)),
					result  => q(五谷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:稻穀)),
					result  => q(稻谷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:包穀)),
					result  => q(包谷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穀殻)),
					result  => q(谷壳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穀穗)),
					result  => q(谷穗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穀種)),
					result  => q(谷种),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穀苗)),
					result  => q(谷苗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穀倉)),
					result  => q(谷仓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穀草)),
					result  => q(谷草),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穀類)),
					result  => q(谷类),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穀粒)),
					result  => q(谷粒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穀物)),
					result  => q(谷物),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穀場)),
					result  => q(谷场),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:打穀)),
					result  => q(打谷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穀子)),
					result  => q(谷子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬼谷子)),
					result  => q(鬼谷子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穀神星)),
					result  => q(谷神星),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:穀賤傷農)),
					result  => q(谷贱伤农),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:製)),
					result  => q(制),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:制)),
					result  => q(制),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:預製)),
					result  => q(预制),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:特製)),
					result  => q(特制),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:炮製)),
					result  => q(炮制),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:釀製)),
					result  => q(酿制),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:煉製)),
					result  => q(炼制),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:巨製)),
					result  => q(巨制),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:縫製)),
					result  => q(缝制),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:製作)),
					result  => q(制作),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:製圖)),
					result  => q(制图),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:製造)),
					result  => q(制造),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:製片)),
					result  => q(制片),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:製品)),
					result  => q(制品),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:製成)),
					result  => q(制成),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:製版)),
					result  => q(制版),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:緻)),
					result  => q(致),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:致)),
					result  => q(致),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:別緻)),
					result  => q(别致),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:標緻)),
					result  => q(标致),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:精緻)),
					result  => q(精致),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:細緻)),
					result  => q(细致),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:气)),
					result  => q(气),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:氣)),
					result  => q(气),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:燄)),
					result  => q(焰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:氣燄)),
					result  => q(气焰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:氣沖沖)),
					result  => q(气冲冲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:万俟)),
					result  => q(万俟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:曆)),
					result  => q(历),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:歷)),
					result  => q(历),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:萬曆)),
					result  => q(万历),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:萬年曆)),
					result  => q(万年历),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:遊歷)),
					result  => q(游历),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:月曆)),
					result  => q(月历),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:陰曆)),
					result  => q(阴历),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:陽曆)),
					result  => q(阳历),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:新曆)),
					result  => q(新历),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:夏曆)),
					result  => q(夏历),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:西曆)),
					result  => q(西历),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:日曆)),
					result  => q(日历),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:黃曆)),
					result  => q(黄历),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:舊曆)),
					result  => q(旧历),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:公曆)),
					result  => q(公历),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:曆法)),
					result  => q(历法),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:曆書)),
					result  => q(历书),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:姦)),
					result  => q(奸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:奸)),
					result  => q(奸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:誘姦)),
					result  => q(诱奸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:通姦)),
					result  => q(通奸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:強姦)),
					result  => q(强奸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輪姦)),
					result  => q(轮奸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:雞姦)),
					result  => q(鸡奸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:姦淫)),
					result  => q(奸淫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:姦污)),
					result  => q(奸污),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:姦情)),
					result  => q(奸情),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:姦婦)),
					result  => q(奸妇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:姦夫)),
					result  => q(奸夫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:傢)),
					result  => q(家),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:家)),
					result  => q(家),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:傢伙)),
					result  => q(家伙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:傢具)),
					result  => q(家具),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:夥)),
					result  => q(伙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:伙)),
					result  => q(伙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:夥伴)),
					result  => q(伙伴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:夥計)),
					result  => q(伙计),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:叶)),
					result  => q(叶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:葉)),
					result  => q(叶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:叶韻)),
					result  => q(叶韵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:儘)),
					result  => q(尽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:盡)),
					result  => q(尽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:儘管)),
					result  => q(尽管),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:藉)),
					result  => q(借),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:借)),
					result  => q(借),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:枕藉)),
					result  => q(枕藉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:藴藉)),
					result  => q(蕴藉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:狼藉)),
					result  => q(狼藉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:慰藉)),
					result  => q(慰借),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:駘藉)),
					result  => q(骀藉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:憑藉)),
					result  => q(凭藉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:藉使)),
					result  => q(借使),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:藉故)),
					result  => q(借故),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:藉口)),
					result  => q(借口),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:人言藉藉)),
					result  => q(人言藉藉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闢)),
					result  => q(辟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:辟)),
					result  => q(辟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闢邪)),
					result  => q(辟邪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:開闢)),
					result  => q(开辟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:開天闢地)),
					result  => q(开天辟地),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:佈)),
					result  => q(布),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:布)),
					result  => q(布),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:宣佈)),
					result  => q(宣布),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:公佈)),
					result  => q(公布),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:發佈)),
					result  => q(发布),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:布穀)),
					result  => q(布谷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:佈置)),
					result  => q(布置),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:佈施)),
					result  => q(布施),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:佈雷)),
					result  => q(布雷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:佈局)),
					result  => q(布局),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:佈景)),
					result  => q(布景),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:佈道)),
					result  => q(布道),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:葯)),
					result  => q(药),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:藥)),
					result  => q(药),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:噹)),
					result  => q(当),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:當)),
					result  => q(当),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:併)),
					result  => q(并),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:並)),
					result  => q(并),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:吞併)),
					result  => q(吞并),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:合併)),
					result  => q(合并),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:併力)),
					result  => q(并力),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:併吞)),
					result  => q(并吞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:併入)),
					result  => q(并入),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:併攏)),
					result  => q(并拢),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:併發)),
					result  => q(并发),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:隻)),
					result  => q(只),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:只)),
					result  => q(只),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:祇)),
					result  => q(祇),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:祇得)),
					result  => q(只得),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:祇有)),
					result  => q(只有),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:祇要)),
					result  => q(只要),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:祇好)),
					result  => q(只好),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:祇管)),
					result  => q(只管),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:艦隻)),
					result  => q(舰只),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:船隻)),
					result  => q(船只),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:隻眼)),
					result  => q(只眼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:隻身)),
					result  => q(只身),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:祇請政安)),
					result  => q(只请政安),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:祇賀新禧)),
					result  => q(只贺新禧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:形單影隻)),
					result  => q(形单影只),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬚)),
					result  => q(须),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:須)),
					result  => q(须),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:觸鬚)),
					result  => q(触须),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:龍鬚)),
					result  => q(龙须),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬚眉)),
					result  => q(须眉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬚鯨)),
					result  => q(须鲸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬚根)),
					result  => q(须根),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:衚)),
					result  => q(胡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬍)),
					result  => q(胡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:胡)),
					result  => q(胡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬍鬚)),
					result  => q(胡须),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬍子)),
					result  => q(胡子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:衚衕)),
					result  => q(胡同),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:檯)),
					result  => q(台),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:臺)),
					result  => q(台),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:颱)),
					result  => q(台),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:台)),
					result  => q(台),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:寫字檯)),
					result  => q(写字台),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:颱風)),
					result  => q(台风),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:征)),
					result  => q(征),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:徵)),
					result  => q(征),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:親征)),
					result  => q(亲征),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:出征)),
					result  => q(出征),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:長征)),
					result  => q(长征),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:征討)),
					result  => q(征讨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:征途)),
					result  => q(征途),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:征服)),
					result  => q(征服),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:征伐)),
					result  => q(征伐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:宮商角徵羽)),
					result  => q(宫商角徵羽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:靦)),
					result  => q(腼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:靦腆)),
					result  => q(腼腆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:禦)),
					result  => q(御),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:御)),
					result  => q(御),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:禦寒)),
					result  => q(御寒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:禦敵)),
					result  => q(御敌),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:防禦)),
					result  => q(防御),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:麵)),
					result  => q(面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:面)),
					result  => q(面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:白麵)),
					result  => q(白面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:發麵)),
					result  => q(发面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鹼麵)),
					result  => q(碱面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:壽麵)),
					result  => q(寿面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:湯麵)),
					result  => q(汤面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:涼麵)),
					result  => q(凉面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:拉麵)),
					result  => q(拉面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擀麵)),
					result  => q(擀面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:炒麵)),
					result  => q(炒面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:甜麵醬)),
					result  => q(甜面酱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:陽春麵)),
					result  => q(阳春面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:空心麵)),
					result  => q(空心面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:刀削麵)),
					result  => q(刀削面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:擔擔麵)),
					result  => q(担担面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:炸醬麵)),
					result  => q(炸酱面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:麵食)),
					result  => q(面食),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:麵筋)),
					result  => q(面筋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:麵包)),
					result  => q(面包),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:麵粉)),
					result  => q(面粉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:麵條)),
					result  => q(面条),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闆)),
					result  => q(板),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:板)),
					result  => q(板),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:老闆)),
					result  => q(老板),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:菓)),
					result  => q(果),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:果)),
					result  => q(果),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬆)),
					result  => q(松),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:松)),
					result  => q(松),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:肉鬆)),
					result  => q(肉松),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:輕鬆)),
					result  => q(轻松),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:放鬆)),
					result  => q(放松),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:酥鬆)),
					result  => q(疏松),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬆弛)),
					result  => q(松弛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬆綁)),
					result  => q(松绑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬆軟)),
					result  => q(松软),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬆手)),
					result  => q(松手),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬆散)),
					result  => q(松散),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬆緊)),
					result  => q(松紧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬆動)),
					result  => q(松动),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:毬果)),
					result  => q(球果),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:毬花)),
					result  => q(球花),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:松毬)),
					result  => q(松球),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:週)),
					result  => q(周),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:周)),
					result  => q(周),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:本週)),
					result  => q(本周),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:週轉)),
					result  => q(周转),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:周遊)),
					result  => q(周游),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:週年)),
					result  => q(周年),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:週歲)),
					result  => q(周岁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:週期)),
					result  => q(周期),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:週刊)),
					result  => q(周刊),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:週末)),
					result  => q(周末),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬭)),
					result  => q(斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:闘)),
					result  => q(斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:斗)),
					result  => q(斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬥)),
					result  => q(斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:星斗)),
					result  => q(星斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:泰斗)),
					result  => q(泰斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:市斗)),
					result  => q(市斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:墨斗)),
					result  => q(墨斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:南斗)),
					result  => q(南斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:熨斗)),
					result  => q(熨斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:漏斗)),
					result  => q(漏斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:北斗)),
					result  => q(北斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:阿斗)),
					result  => q(阿斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:斗子)),
					result  => q(斗子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:斗拱)),
					result  => q(斗拱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:斗城)),
					result  => q(斗城),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:斗室)),
					result  => q(斗室),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:斗胆)),
					result  => q(斗胆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:斗量)),
					result  => q(斗量),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:畫)),
					result  => q(画),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劃)),
					result  => q(划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:划)),
					result  => q(划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:刻劃)),
					result  => q(刻画),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:板畫)),
					result  => q(版画),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:區畫)),
					result  => q(区划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:區劃)),
					result  => q(区划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謀畫)),
					result  => q(谋划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:謀劃)),
					result  => q(谋划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:比畫)),
					result  => q(比划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:比劃)),
					result  => q(比划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:計畫)),
					result  => q(计划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:計劃)),
					result  => q(计划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籌畫)),
					result  => q(筹划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:籌劃)),
					result  => q(筹划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:策畫)),
					result  => q(策划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:策劃)),
					result  => q(策划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:規畫)),
					result  => q(规划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:規劃)),
					result  => q(规划),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:畫清)),
					result  => q(划清),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劃清)),
					result  => q(划清),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:畫歸)),
					result  => q(划归),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劃歸)),
					result  => q(划归),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:畫策)),
					result  => q(划策),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劃策)),
					result  => q(划策),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:畫界)),
					result  => q(划界),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劃界)),
					result  => q(划界),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:畫一)),
					result  => q(划一),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劃一)),
					result  => q(划一),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:畫開)),
					result  => q(划开),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劃開)),
					result  => q(划开),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:畫分)),
					result  => q(划分),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劃分)),
					result  => q(划分),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:劃時代)),
					result  => q(划时代),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:干)),
					result  => q(干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幹)),
					result  => q(干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:乾)),
					result  => q(干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:乾坤)),
					result  => q(乾坤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:乾麵)),
					result  => q(干面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:相干)),
					result  => q(相干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:無干)),
					result  => q(无干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:天干)),
					result  => q(天干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:若干)),
					result  => q(若干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:干系)),
					result  => q(干系),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:干預)),
					result  => q(干预),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:干擾)),
					result  => q(干扰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:干連)),
					result  => q(干连),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:干支)),
					result  => q(干支),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:干涉)),
					result  => q(干涉),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:干戈)),
					result  => q(干戈),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:干犯)),
					result  => q(干犯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:干貝)),
					result  => q(干贝),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:主幹)),
					result  => q(主干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:枝幹)),
					result  => q(枝干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:單幹)),
					result  => q(调干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:樹幹)),
					result  => q(树干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:實幹)),
					result  => q(实干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:強幹)),
					result  => q(强干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:能幹)),
					result  => q(能干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:腦幹)),
					result  => q(脑干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:苦幹)),
					result  => q(苦干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:骨幹)),
					result  => q(骨干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:高幹)),
					result  => q(高干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:才幹)),
					result  => q(才干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:包幹)),
					result  => q(包干),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幹線)),
					result  => q(干线),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幹事)),
					result  => q(干事),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幹嗎)),
					result  => q(干吗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幹練)),
					result  => q(干练),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幹勁)),
					result  => q(干劲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幹道)),
					result  => q(干道),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幹才)),
					result  => q(干才),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幹部)),
					result  => q(干部),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:幹甚麼)),
					result  => q(干什么),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裏)),
					result  => q(里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裡)),
					result  => q(里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裡外)),
					result  => q(里外),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裡邊)),
					result  => q(里边),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裡頭)),
					result  => q(里头),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裡屋)),
					result  => q(里屋),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裡間)),
					result  => q(里间),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裡層)),
					result  => q(里层),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裡面)),
					result  => q(里面),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裡快)),
					result  => q(里快),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裡手)),
					result  => q(里手),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裡海)),
					result  => q(里海),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裡子)),
					result  => q(里子),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裡襯)),
					result  => q(里衬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裡通外國)),
					result  => q(里通外国),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裡應外合)),
					result  => q(里应外合),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:裡裡外外)),
					result  => q(里里外外),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:入裡)),
					result  => q(入里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:哪裡)),
					result  => q(哪里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:那裡)),
					result  => q(那里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:這裡)),
					result  => q(这里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:肚裡)),
					result  => q(肚里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:懷裡)),
					result  => q(怀里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:頭裡)),
					result  => q(头里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:心裡)),
					result  => q(心里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:口裡)),
					result  => q(口里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嘴裡)),
					result  => q(嘴里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:眼裡)),
					result  => q(眼里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:手裡)),
					result  => q(手里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:內裡)),
					result  => q(內里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:表裡)),
					result  => q(表里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:字裡)),
					result  => q(字里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:暗裡)),
					result  => q(暗里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:明裡)),
					result  => q(明里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:苑裡)),
					result  => q(苑里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:園裡)),
					result  => q(园里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:行裡)),
					result  => q(行里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:院裡)),
					result  => q(院里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:連裡)),
					result  => q(连里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:房裡)),
					result  => q(房里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:屋裡)),
					result  => q(屋里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:家裡)),
					result  => q(家里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:門裡)),
					result  => q(门里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:關裡)),
					result  => q(关里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:班裡)),
					result  => q(班里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:隊裡)),
					result  => q(队里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:部裡)),
					result  => q(部里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:館裡)),
					result  => q(馆里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:店裡)),
					result  => q(店里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:廠裡)),
					result  => q(厂里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:段裡)),
					result  => q(段里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:站裡)),
					result  => q(站里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:村裡)),
					result  => q(村里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:市裡)),
					result  => q(市里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:城裡)),
					result  => q(城里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鎮裡)),
					result  => q(镇里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:省裡)),
					result  => q(省里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:夜裡)),
					result  => q(夜里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:霧裡)),
					result  => q(雾里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:雨裡)),
					result  => q(雨里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:風裡)),
					result  => q(风里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:雪裡)),
					result  => q(雪里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:沙裡)),
					result  => q(沙里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:江裡)),
					result  => q(江里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:河裡)),
					result  => q(河里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:溝裡)),
					result  => q(沟里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:田裡)),
					result  => q(田里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:花裡)),
					result  => q(花里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:地裡)),
					result  => q(地里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:山裡)),
					result  => q(山里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:浪裡)),
					result  => q(浪里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:海裡)),
					result  => q(海里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:死裡)),
					result  => q(死里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:聞裡)),
					result  => q(闻里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:忙裡)),
					result  => q(忙里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:窩裡鬥)),
					result  => q(窝里斗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:骨子裡)),
					result  => q(骨子里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:私下裡)),
					result  => q(私下里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:白裡透紅)),
					result  => q(白里透红),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:百裡挑一)),
					result  => q(百里挑一),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:由表及裡)),
					result  => q(由表及里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:稀裡嘩啦)),
					result  => q(稀里哗啦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:土裡土氣)),
					result  => q(土里土气),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:寶裡寶氣)),
					result  => q(宝里宝气),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:洋裡洋氣)),
					result  => q(洋里洋气),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嬌裡嬌氣)),
					result  => q(娇里娇气),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:妖裡妖氣)),
					result  => q(妖里妖气),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:女裡女氣)),
					result  => q(女里女气),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:嗲裡嗲氣)),
					result  => q(嗲里嗲气),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:俗裡俗氣)),
					result  => q(俗里俗气),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:傻裡傻氣)),
					result  => q(傻里傻气),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:怪裡怪氣)),
					result  => q(怪里怪气),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:蒙在鼓裡)),
					result  => q(蒙在鼓里),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:稀裡糊塗)),
					result  => q(稀里糊涂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:糊裡糊塗)),
					result  => q(糊里糊涂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繫)),
					result  => q(系),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:係)),
					result  => q(系),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:系)),
					result  => q(系),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:連繫)),
					result  => q(连系),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:維繫)),
					result  => q(维系),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繫於)),
					result  => q(系于),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:聯繫)),
					result  => q(联系),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:關係)),
					result  => q(关系),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繫念)),
					result  => q(系念),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繫辭)),
					result  => q(系辞),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:繫詞)),
					result  => q(系词),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:解鈴繫鈴)),
					result  => q(解铃系铃),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瞭)),
					result  => q(了),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:了)),
					result  => q(了),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:明瞭)),
					result  => q(明了),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瞭望)),
					result  => q(了望),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瞭解)),
					result  => q(了解),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:瞭然)),
					result  => q(了然),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:複)),
					result  => q(复),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:復)),
					result  => q(复),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:複製)),
					result  => q(复制),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:複雜)),
					result  => q(复杂),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:複分數)),
					result  => q(复分数),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:複數)),
					result  => q(复数),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:么)),
					result  => q(么),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:麽)),
					result  => q(么),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:麼)),
					result  => q(么),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:甚麼)),
					result  => q(什么),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘)),
					result  => q(余),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:余)),
					result  => q(余),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:盈餘)),
					result  => q(盈余),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:業餘)),
					result  => q(业余),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:其餘)),
					result  => q(其余),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:剩餘)),
					result  => q(剩余),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:殘餘)),
					result  => q(残余),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:有餘)),
					result  => q(有余),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:多餘)),
					result  => q(多余),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:結餘)),
					result  => q(结余),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘震)),
					result  => q(余震),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘錢)),
					result  => q(余钱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘音)),
					result  => q(余音),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘孽)),
					result  => q(余孽),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘杭)),
					result  => q(余杭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘裕)),
					result  => q(余裕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘慶)),
					result  => q(余庆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘切)),
					result  => q(余切),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘興)),
					result  => q(余兴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘生)),
					result  => q(余生),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘力)),
					result  => q(余力),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘年)),
					result  => q(余年),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘糧)),
					result  => q(余粮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘量)),
					result  => q(余量),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘款)),
					result  => q(余款),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘燼)),
					result  => q(余烬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘角)),
					result  => q(余角),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘額)),
					result  => q(余额),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘地)),
					result  => q(余地),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘波)),
					result  => q(余波),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘勇可賈)),
					result  => q(余勇可贾),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘音繞梁)),
					result  => q(余音绕梁),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:餘怒未消)),
					result  => q(余怒未消),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:茶餘飯後)),
					result  => q(茶余饭后),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:麯)),
					result  => q(曲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:曲)),
					result  => q(曲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:侖)),
					result  => q(仑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:崙)),
					result  => q(仑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:崑)),
					result  => q(昆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:崑曲)),
					result  => q(昆曲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:崑崙)),
					result  => q(昆仑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:崑山)),
					result  => q(昆山),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:崙頂)),
					result  => q(仑顶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:中崙)),
					result  => q(中仑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:下崙)),
					result  => q(下仑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:金崙溪)),
					result  => q(金仑溪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:赤皮崙)),
					result  => q(赤皮仑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:薑)),
					result  => q(姜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:姜)),
					result  => q(姜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鬼子薑)),
					result  => q(鬼子姜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:生薑)),
					result  => q(生姜),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:薑末)),
					result  => q(姜末),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:薑片)),
					result  => q(姜片),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:鮮于)),
					result  => q(鲜于),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:單于)),
					result  => q(单于),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:于思)),
					result  => q(于思),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:于歸)),
					result  => q(于归),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:于飛)),
					result  => q(于飞),
					revisit => 0,
				},
			]
		},
	] },
);

no Moose;
__PACKAGE__->meta->make_immutable;

1;

# vim: tabstop=4
